@@ -149,8 +149,9 @@ bool CASpreadsheetHandler::openDocument (const QString& uri)
 
 QStringList CASpreadsheetHandler::supportedMimetypes()
 {
-    QStringList supportedTypes;
-    supportedTypes << "application/vnd.oasis.opendocument.spreadsheet" << "application/vnd.ms-excel";
+    // keep in sync with spreadsheet related mimetypes in calligraactive.desktop
+    const QStringList supportedTypes =
+        QString::fromLatin1("application/vnd.oasis.opendocument.spreadsheet;application/x-kspread;application/vnd.ms-excel;text/csv;application/x-quattropro;application/vnd.openxmlformats-officedocument.spreadsheetml.sheet;application/vnd.openxmlformats-officedocument.spreadsheetml.template;").split(';', QString::SkipEmptyParts);
     return supportedTypes;
 }
 
