@@ -124,7 +124,7 @@ void WordsTableHandler::tableStart(Words::Table* table)
         }
         //style:vertical-rel - relative vertical position of the anchor
         pos = Conversion::getVerticalRel(tap->pcVert);
-    if (!pos.isEmpty()) {
+	if (!pos.isEmpty()) {
             style.addProperty("style:vertical-rel", pos, gt);
         }
         //style:horizontal-rel - relative horizontal position of the anchor
@@ -678,6 +678,11 @@ void WordsTableHandler::tableCellEnd()
     }
 }
 
+Words::Table::Table()
+: floating(false)
+{
+}
+
 void Words::Table::cacheCellEdge(int cellEdge)
 {
     kDebug(30513) ;
