@@ -468,7 +468,7 @@ void KarbonGradientTool::deactivate()
     canvas()->snapGuide()->reset();
 }
 
-void KarbonGradientTool::resourceChanged(int key, const QVariant & res)
+void KarbonGradientTool::documentResourceChanged(int key, const QVariant & res)
 {
     switch (key) {
     case KoDocumentResourceManager::HandleRadius:
