@@ -20,8 +20,8 @@
 #include "kexistartupdata.h"
 #include "kexi.h"
 
-#include <kexidb/driver.h>
-#include <kexidb/drivermanager.h>
+#include <db/driver.h>
+#include <db/drivermanager.h>
 
 #include <QFileInfo>
 
