@@ -1,6 +1,6 @@
 /* This file is part of the KDE project
    Copyright (C) 2003 Lucijan Busch <lucijan@kde.org>
-   Copyright (C) 2003-2012 Jarosław Staniek <staniek@kde.org>
+   Copyright (C) 2003-2013 Jarosław Staniek <staniek@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -612,8 +612,16 @@ public:
                 if (index == KEXITABBEDTOOLBAR_SPACER_TAB_INDEX)
                     return;
                 bool mouseOver = opt->state & QStyle::State_MouseOver;
+                bool unselectedOrMenuVisible
+                    = !(opt->state & State_Selected) || tbar->mainMenuVisible();
+                if (unselectedOrMenuVisible) {
+                    if (parentStyle()->objectName() == "bespin") {
+                        unselectedOrMenuVisible = false;
+                    }
+                }
+
                 if (!mouseOver
-                    && (!(opt->state & State_Selected) || tbar->mainMenuVisible())
+                    && unselectedOrMenuVisible
                     && index > 0)
                 {
                     QStyleOptionTabV2 newOpt(*opt);
@@ -813,7 +821,8 @@ void KexiTabbedToolBar::Private::updateMainMenuGeometry()
 
     QStyleOptionTab ot;
     ot.initFrom(tabBar);
-    int overlap = tabBar->style()->pixelMetric(QStyle::PM_TabBarBaseOverlap, &ot, tabBar) - 2;
+    int overlap = tabBar->style()->pixelMetric(QStyle::PM_TabBarBaseOverlap, &ot, tabBar)
+                  - tabBar->style()->pixelMetric(QStyle::PM_TabBarBaseHeight, &ot, tabBar);
 //     kDebug() << "4. overlap=" << overlap;
 
     mainMenu->setGeometry(0, pos.y() - overlap /*- q->y()*/,
