@@ -157,6 +157,7 @@ class KexiSearchLineEditCompleter : public KexiCompleter
 {
 public:
     KexiSearchLineEditCompleter(QObject *parent = 0) : KexiCompleter(parent) {
+        setCompletionRole(Qt::DisplayRole);
     }
 
     virtual QString pathFromIndex(const QModelIndex &index) const {
@@ -506,7 +507,9 @@ void KexiSearchLineEdit::focusOutEvent(QFocusEvent *e)
     update();
     if (e->reason() == Qt::TabFocusReason || e->reason() == Qt::BacktabFocusReason) {
         // go back to previously focused widget
-        d->previouslyFocusedWidget->setFocus();
+        if (d->previouslyFocusedWidget) {
+            d->previouslyFocusedWidget->setFocus();
+        }
         e->accept();
     }
     d->previouslyFocusedWidget = 0;
