@@ -20,8 +20,8 @@
 #ifndef KEXIWELCOMEASSISTANT_H
 #define KEXIWELCOMEASSISTANT_H
 
-#include <kexidb/connectiondata.h>
-#include <kexidb/msghandler.h>
+#include <db/connectiondata.h>
+#include <db/msghandler.h>
 #include <kexiutils/KexiContextMessage.h>
 #include <kexiutils/KexiAssistantPage.h>
 #include <kexiutils/KexiAssistantWidget.h>
