@@ -26,11 +26,11 @@
 
 #include <kexiutils/validator.h>
 
-#include <kexidb/field.h>
-#include <kexidb/roweditbuffer.h>
-#include <kexidb/cursor.h>
-#include <kexidb/utils.h>
-#include <kexidb/error.h>
+#include <db/field.h>
+#include <db/roweditbuffer.h>
+#include <db/cursor.h>
+#include <db/utils.h>
+#include <db/error.h>
 #include <kexi.h>
 
 #include <kdebug.h>
