@@ -31,15 +31,14 @@
 #include <QLineEdit>
 
 #include <kdebug.h>
-#include <kiconloader.h>
 
 #include <kconfig.h>
 #include <kglobalsettings.h>
 #include <klocale.h>
 
-#include <kexidb/tableschema.h>
-#include <kexidb/queryschema.h>
-#include <kexidb/utils.h>
+#include <db/tableschema.h>
+#include <db/queryschema.h>
+#include <db/utils.h>
 #include <kexiutils/utils.h>
 #include <kexidragobjects.h>
 #include <kexiproject.h>
