@@ -689,6 +689,12 @@ protected:
     /*! Implementation for KexiDataItemChangesListener. */
     virtual bool cursorAtNewRow() const;
 
+    /*! Implementation for KexiDataItemChangesListener. */
+    virtual void lengthExceeded(KexiDataItemInterface *item, bool lengthExceeded);
+
+    /*! Implementation for KexiDataItemChangesListener. */
+    virtual void updateLengthExceededMessage(KexiDataItemInterface *item);
+
     virtual int horizontalHeaderHeight() const;
 
     QWidget* navPanelWidget() const;
