@@ -91,7 +91,7 @@ QRect KisTransformWorker::rotateNone(KisPaintDeviceSP src, KisPaintDeviceSP dst,
 {
     qint32 pixelSize = src->pixelSize();
     QRect r(boundRect);
-    KoColorSpace *cs = src->colorSpace();
+    const KoColorSpace *cs = src->colorSpace();
     Q_UNUSED(cs);
 
     KisHLineIteratorSP hit = src->createHLineIteratorNG(r.x(), r.top(), r.width());
@@ -128,7 +128,7 @@ QRect rotateWithTf(int rotation, KisPaintDeviceSP src, KisPaintDeviceSP dst,
 {
     qint32 pixelSize = src->pixelSize();
     QRect r(boundRect);
-    KoColorSpace *cs = src->colorSpace();
+    const KoColorSpace *cs = src->colorSpace();
     Q_UNUSED(cs);
 
     KisRandomAccessorSP srcAcc = src->createRandomAccessorNG(0, 0);
@@ -296,7 +296,7 @@ void KisTransformWorker::transformPass(KisPaintDevice *src, KisPaintDevice *dst,
     qint32 lineNum, srcStart, firstLine, srcLen, numLines;
     qint32 center, begin, end;    /* filter calculation variables */
     quint8 pixelSize = src->pixelSize();
-    KoColorSpace * cs = src->colorSpace();
+    const KoColorSpace * cs = src->colorSpace();
     KoMixColorsOp * mixOp = cs->mixColorsOp();
     qint32 scale;
     qint32 shearFracOffset;
@@ -674,7 +674,7 @@ bool KisTransformWorker::run()
     return true;
 }
 
-QRect KisTransformWorker::mirrorX(KisPaintDeviceSP dev, const KisSelection* selection)
+QRect KisTransformWorker::mirrorX(KisPaintDeviceSP dev, qreal axis, const KisSelection* selection)
 {
 
     int pixelSize = dev->pixelSize();
@@ -690,6 +690,13 @@ QRect KisTransformWorker::mirrorX(KisPaintDeviceSP dev, const KisSelection* sele
             r = dev->dataManager()->extent();
         else
             r = dev->exactBounds();
+
+        if (axis > 0) {
+            // Extend rect so it has the same width on both sides of the axis
+            qreal distanceFromAxis = qMax(fabs((qreal)r.left() - axis), fabs((qreal)r.right() - axis));
+            QRect newRect(floor(axis - distanceFromAxis), r.y(), ceil(2*distanceFromAxis), r.height());
+            r = newRect.adjusted(-1, 0, 2, 0);
+        }
     }
 
     if (r.width() <= 1) return r;
@@ -742,7 +749,7 @@ QRect KisTransformWorker::mirrorX(KisPaintDeviceSP dev, const KisSelection* sele
     return r;
 }
 
-QRect KisTransformWorker::mirrorY(KisPaintDeviceSP dev, const KisSelection* selection)
+QRect KisTransformWorker::mirrorY(KisPaintDeviceSP dev, qreal axis, const KisSelection* selection)
 {
     int pixelSize = dev->pixelSize();
     KisPaintDeviceSP dst = new KisPaintDevice(dev->colorSpace());
@@ -757,6 +764,13 @@ QRect KisTransformWorker::mirrorY(KisPaintDeviceSP dev, const KisSelection* sele
             r = dev->dataManager()->extent();
         else
             r = dev->exactBounds();
+
+        if (axis > 0) {
+            // Extend rect so it has the same height on both sides of the axis
+            qreal distanceFromAxis = qMax(fabs((qreal)r.top() - axis), fabs((qreal)r.bottom() - axis));
+            QRect newRect(r.x(), floor(axis - distanceFromAxis), r.width(), ceil(2*distanceFromAxis));
+            r = newRect.adjusted(0, -1, 0, 2);
+        }
     }
     {
         qint32 y1, y2;
