@@ -61,13 +61,19 @@ public:
 
     /**
      * Mirror the specified device along the X axis
+     * @param dev device to be mirrored
+     * @param axis the axis around which the device will be mirrored, only used if greater zero
+     * @param selection optional selection that will be used for the mirror
      */
-    static QRect mirrorX(KisPaintDeviceSP dev, const KisSelection* selection = 0);
+    static QRect mirrorX(KisPaintDeviceSP dev, qreal axis = -1.0f, const KisSelection* selection = 0);
 
     /**
      * Mirror the specified device along the Y axis
+     * @param dev device to be mirrored
+     * @param axis the axis around which the device will be mirrored, only used if greater zero
+     * @param selection optional selection that will be used for the mirror
      */
-    static QRect mirrorY(KisPaintDeviceSP dev, const KisSelection* selection = 0);
+    static QRect mirrorY(KisPaintDeviceSP dev, qreal axis = -1.0f, const KisSelection* selection = 0);
 
 
 public:
