@@ -21,7 +21,7 @@
 #include "kis_pdf_import.h"
 
 // poppler's headers
-#include <poppler-qt4.h>
+#include <poppler/qt4/poppler-qt4.h>
 
 // Qt's headers
 #include <QFile>
