@@ -123,8 +123,14 @@ void KisToolInvocationAction::inputEvent(QEvent* event)
     }
 }
 
+bool KisToolInvocationAction::supportsHiResInputEvents() const
+{
+    return true;
+}
+
 QPointF KisToolInvocationAction::Private::tabletToPixel(const QPointF &globalPos)
 {
     const QPointF pos = globalPos - q->inputManager()->canvas()->canvasWidget()->mapToGlobal(QPoint(0, 0));
     return q->inputManager()->widgetToPixel(pos);
 }
+
