@@ -137,6 +137,12 @@ void KisOpenRasterStackLoadVisitor::loadLayerInfo(const QDomElement& elem, KisLa
         if (compop == "svg:hard-light") layer->setCompositeOp(COMPOSITE_HARD_LIGHT);
         if (compop == "svg:soft-light") layer->setCompositeOp(COMPOSITE_SOFT_LIGHT);
         if (compop == "svg:difference") layer->setCompositeOp(COMPOSITE_DIFF);
+        if (compop == "difference") layer->setCompositeOp(COMPOSITE_DIFF); // to fix an old bug in krita's ora export
+        if (compop == "svg:color") layer->setCompositeOp(COMPOSITE_COLOR);
+        if (compop == "svg:luminosity") layer->setCompositeOp(COMPOSITE_LUMINIZE);
+        if (compop == "svg:hue") layer->setCompositeOp(COMPOSITE_HUE);
+        if (compop == "svg:saturation") layer->setCompositeOp(COMPOSITE_SATURATION);
+
     }
     else if (compop.startsWith("krita:")) {
         compop = compop.remove(0, 6);
