@@ -88,9 +88,9 @@ public:
 
 void KisDoc2Test::testUndoRedoNotify()
 {
-    KisPart2 *p = new KisPart2();
-    KisDoc2 doc(p);
-    p->setDocument(&doc);
+    KisPart2 part;
+    KisDoc2 doc(&part);
+    part.setDocument(&doc);
 
     doc.initEmpty();
 
@@ -163,9 +163,10 @@ void KisDoc2Test::testOpenImageTwiceInSameDoc()
 
     Q_ASSERT(!fname.isEmpty());
     Q_ASSERT(!fname2.isEmpty());
-    KisPart2 *p = new KisPart2();
-    KisDoc2 doc(p);
-    p->setDocument(&doc);
+
+    KisPart2 part;
+    KisDoc2 doc(&part);
+    part.setDocument(&doc);
 
     doc.loadNativeFormat(fname);
     doc.loadNativeFormat(fname2);
