@@ -129,6 +129,8 @@ void KisPainterBasedStrokeStrategy::initStrokeCallback()
     KisLayerSP layer = dynamic_cast<KisLayer*>(node.data());
     if(layer) {
         selection = layer->selection();
+    } else {
+        selection = m_resources->image()->globalSelection();
     }
 
     m_transaction = new KisTransaction(name(), targetDevice);
