@@ -109,6 +109,7 @@ KoShapePrivate::KoShapePrivate(KoShape *shape)
     connectors[KoConnectionPoint::RightConnectionPoint] = KoConnectionPoint::defaultConnectionPoint(KoConnectionPoint::RightConnectionPoint);
     connectors[KoConnectionPoint::BottomConnectionPoint] = KoConnectionPoint::defaultConnectionPoint(KoConnectionPoint::BottomConnectionPoint);
     connectors[KoConnectionPoint::LeftConnectionPoint] = KoConnectionPoint::defaultConnectionPoint(KoConnectionPoint::LeftConnectionPoint);
+    connectors[KoConnectionPoint::FirstCustomConnectionPoint] = KoConnectionPoint(QPointF(0.5, 0.5), KoConnectionPoint::AllDirections, KoConnectionPoint::AlignCenter);
 }
 
 KoShapePrivate::~KoShapePrivate()
@@ -1679,6 +1680,7 @@ void KoShape::loadOdfGluePoints(const KoXmlElement &element, KoShapeLoadingConte
     Q_D(KoShape);
 
     KoXmlElement child;
+    bool hasCenterGluePoint = false;
     forEachElement(child, element) {
         if (child.namespaceURI() != KoXmlNS::draw)
             continue;
@@ -1690,7 +1692,11 @@ void KoShape::loadOdfGluePoints(const KoXmlElement &element, KoShapeLoadingConte
         // doesn't support xml:id (and so, maybe, shouldn't use KoElementReference.
         const QString id = child.attributeNS(KoXmlNS::draw, "id", QString());
         const int index = id.toInt();
-        if(id.isEmpty() || index < 4 || d->connectors.contains(index)) {
+        // connection point in center should be default but odf doesn't support,
+        // in new shape, first custom point is in center, it's okay to replace that point
+        // with point from xml now, we'll add it back later
+        if(id.isEmpty() || index < KoConnectionPoint::FirstCustomConnectionPoint ||
+                (index != KoConnectionPoint::FirstCustomConnectionPoint && d->connectors.contains(index))) {
             kWarning(30006) << "glue-point with no or invalid id";
             continue;
         }
@@ -1764,6 +1770,14 @@ void KoShape::loadOdfGluePoints(const KoXmlElement &element, KoShapeLoadingConte
         }
         d->connectors[index] = connector;
         kDebug(30006) << "loaded glue-point" << index << "at position" << connector.position;
+        if (d->connectors[index].position == QPointF(0.5, 0.5)) {
+            hasCenterGluePoint = true;
+            kDebug(30006) << "center glue-point found at id " << index;
+        }
+    }
+    if (!hasCenterGluePoint) {
+        d->connectors[d->connectors.count()] = KoConnectionPoint(QPointF(0.5, 0.5),
+                     KoConnectionPoint::AllDirections, KoConnectionPoint::AlignCenter);
     }
     kDebug(30006) << "shape has now" << d->connectors.count() << "glue-points";
 }
