@@ -50,8 +50,9 @@
 #include "KoSnapGuide.h"
 #include "KoShapeController.h"
 
+#include <KoIcon.h>
+
 #include <KAction>
-#include <KIcon>
 #include <KDebug>
 #include <KLocale>
 #include <QPainter>
@@ -95,75 +96,75 @@ struct KoPathTool::PathSegment {
 
 KoPathTool::KoPathTool(KoCanvasBase *canvas)
         : KoToolBase(canvas)
+        , m_pointSelection(this)
         , m_activeHandle(0)
         , m_handleRadius(3)
-        , m_pointSelection(this)
         , m_activeSegment(0)
         , m_currentStrategy(0)
 {
     QActionGroup *points = new QActionGroup(this);
     // m_pointTypeGroup->setExclusive(true);
-    m_actionPathPointCorner = new KAction(KIcon("pathpoint-corner"), i18n("Corner point"), this);
+    m_actionPathPointCorner = new KAction(koIcon("pathpoint-corner"), i18n("Corner point"), this);
     addAction("pathpoint-corner", m_actionPathPointCorner);
     m_actionPathPointCorner->setData(KoPathPointTypeCommand::Corner);
     points->addAction(m_actionPathPointCorner);
 
-    m_actionPathPointSmooth = new KAction(KIcon("pathpoint-smooth"), i18n("Smooth point"), this);
+    m_actionPathPointSmooth = new KAction(koIcon("pathpoint-smooth"), i18n("Smooth point"), this);
     addAction("pathpoint-smooth", m_actionPathPointSmooth);
     m_actionPathPointSmooth->setData(KoPathPointTypeCommand::Smooth);
     points->addAction(m_actionPathPointSmooth);
 
-    m_actionPathPointSymmetric = new KAction(KIcon("pathpoint-symmetric"), i18n("Symmetric Point"), this);
+    m_actionPathPointSymmetric = new KAction(koIcon("pathpoint-symmetric"), i18n("Symmetric Point"), this);
     addAction("pathpoint-symmetric", m_actionPathPointSymmetric);
     m_actionPathPointSymmetric->setData(KoPathPointTypeCommand::Symmetric);
     points->addAction(m_actionPathPointSymmetric);
 
-    m_actionCurvePoint = new KAction(KIcon("pathpoint-curve"), i18n("Make curve point"), this);
+    m_actionCurvePoint = new KAction(koIcon("pathpoint-curve"), i18n("Make curve point"), this);
     addAction("pathpoint-curve", m_actionCurvePoint);
     connect(m_actionCurvePoint, SIGNAL(triggered()), this, SLOT(pointToCurve()));
 
-    m_actionLinePoint = new KAction(KIcon("pathpoint-line"), i18n("Make line point"), this);
+    m_actionLinePoint = new KAction(koIcon("pathpoint-line"), i18n("Make line point"), this);
     addAction("pathpoint-line", m_actionLinePoint);
     connect(m_actionLinePoint, SIGNAL(triggered()), this, SLOT(pointToLine()));
 
-    m_actionLineSegment = new KAction(KIcon("pathsegment-line"), i18n("Segment to Line"), this);
+    m_actionLineSegment = new KAction(koIcon("pathsegment-line"), i18n("Segment to Line"), this);
     m_actionLineSegment->setShortcut(Qt::Key_F);
     addAction("pathsegment-line", m_actionLineSegment);
     connect(m_actionLineSegment, SIGNAL(triggered()), this, SLOT(segmentToLine()));
 
-    m_actionCurveSegment = new KAction(KIcon("pathsegment-curve"), i18n("Segment to Curve"), this);
+    m_actionCurveSegment = new KAction(koIcon("pathsegment-curve"), i18n("Segment to Curve"), this);
     m_actionCurveSegment->setShortcut(Qt::Key_C);
     addAction("pathsegment-curve", m_actionCurveSegment);
     connect(m_actionCurveSegment, SIGNAL(triggered()), this, SLOT(segmentToCurve()));
 
-    m_actionAddPoint = new KAction(KIcon("pathpoint-insert"), i18n("Insert point"), this);
+    m_actionAddPoint = new KAction(koIcon("pathpoint-insert"), i18n("Insert point"), this);
     addAction("pathpoint-insert", m_actionAddPoint);
     m_actionAddPoint->setShortcut(Qt::Key_Insert);
     connect(m_actionAddPoint, SIGNAL(triggered()), this, SLOT(insertPoints()));
 
-    m_actionRemovePoint = new KAction(KIcon("pathpoint-remove"), i18n("Remove point"), this);
+    m_actionRemovePoint = new KAction(koIcon("pathpoint-remove"), i18n("Remove point"), this);
     m_actionRemovePoint->setShortcut(Qt::Key_Backspace);
     addAction("pathpoint-remove", m_actionRemovePoint);
     connect(m_actionRemovePoint, SIGNAL(triggered()), this, SLOT(removePoints()));
 
-    m_actionBreakPoint = new KAction(KIcon("path-break-point"), i18n("Break at point"), this);
+    m_actionBreakPoint = new KAction(koIcon("path-break-point"), i18n("Break at point"), this);
     addAction("path-break-point", m_actionBreakPoint);
     connect(m_actionBreakPoint, SIGNAL(triggered()), this, SLOT(breakAtPoint()));
 
-    m_actionBreakSegment = new KAction(KIcon("path-break-segment"), i18n("Break at segment"), this);
+    m_actionBreakSegment = new KAction(koIcon("path-break-segment"), i18n("Break at segment"), this);
     addAction("path-break-segment", m_actionBreakSegment);
     connect(m_actionBreakSegment, SIGNAL(triggered()), this, SLOT(breakAtSegment()));
 
-    m_actionJoinSegment = new KAction(KIcon("pathpoint-join"), i18n("Join with segment"), this);
+    m_actionJoinSegment = new KAction(koIcon("pathpoint-join"), i18n("Join with segment"), this);
     m_actionJoinSegment->setShortcut(Qt::Key_J);
     addAction("pathpoint-join", m_actionJoinSegment);
     connect(m_actionJoinSegment, SIGNAL(triggered()), this, SLOT(joinPoints()));
 
-    m_actionMergePoints = new KAction(KIcon("pathpoint-merge"), i18n("Merge points"), this);
+    m_actionMergePoints = new KAction(koIcon("pathpoint-merge"), i18n("Merge points"), this);
     addAction("pathpoint-merge", m_actionMergePoints);
     connect(m_actionMergePoints, SIGNAL(triggered()), this, SLOT(mergePoints()));
 
-    m_actionConvertToPath = new KAction(KIcon("convert-to-path"), i18n("To Path"), this);
+    m_actionConvertToPath = new KAction(koIcon("convert-to-path"), i18n("To Path"), this);
     m_actionConvertToPath->setShortcut(Qt::Key_P);
     addAction("convert-to-path", m_actionConvertToPath);
     connect(m_actionConvertToPath, SIGNAL(triggered()), this, SLOT(convertToPath()));
@@ -184,6 +185,9 @@ KoPathTool::KoPathTool(KoCanvasBase *canvas)
 
 KoPathTool::~KoPathTool()
 {
+    delete m_activeHandle;
+    delete m_activeSegment;
+    delete m_currentStrategy;
 }
 
 QList<QWidget *>  KoPathTool::createOptionWidgets()
@@ -922,7 +926,7 @@ void KoPathTool::deactivate()
     d->canvas->snapGuide()->reset();
 }
 
-void KoPathTool::resourceChanged(int key, const QVariant & res)
+void KoPathTool::documentResourceChanged(int key, const QVariant & res)
 {
     if (key == KoDocumentResourceManager::HandleRadius) {
         int oldHandleRadius = m_handleRadius;
