@@ -40,7 +40,11 @@
 #include <QGraphicsSceneMouseEvent>
 #include <QMenu>
 #include <QMessageBox>
+#include <KStandardGuiItem>
+#include <KGuiItem>
+#include <KStandardAction>
 
+#include <KoIcon.h>
 #include <koproperty/EditorView.h>
 #include <KoRuler.h>
 #include <KoZoomHandler.h>
@@ -610,8 +614,10 @@ void KoReportDesigner::createProperties()
     m_title = new KoProperty::Property("Title", "Report", i18n("Title"), i18n("Report Title"));
 
     keys.clear();
-    keys = pageFormats();
-    m_pageSize = new KoProperty::Property("page-size", keys, keys, "A4", i18n("Page Size"));
+    keys =  KoPageFormat::pageFormatNames();
+    strings = KoPageFormat::localizedPageFormatNames();
+    QString defaultKey = KoPageFormat::formatString(KoPageFormat::defaultFormat());
+    m_pageSize = new KoProperty::Property("page-size", keys, strings, defaultKey, i18n("Page Size"));
 
     keys.clear(); strings.clear();
     keys << "portrait" << "landscape";
@@ -699,13 +705,6 @@ void KoReportDesigner::slotPageButton_Pressed()
     }
 }
 
-QStringList KoReportDesigner::pageFormats() const
-{
-    QStringList lst;
-    lst << "A4" << "Letter" << "Legal" << "A3" << "A5";
-    return lst;
-}
-
 QSize KoReportDesigner::sizeHint() const
 {
     int w = 0;
@@ -821,34 +820,32 @@ void KoReportDesigner::setGridOptions(bool vis, int div)
 void KoReportDesigner::sectionContextMenuEvent(ReportScene * s, QGraphicsSceneContextMenuEvent * e)
 {
     QMenu pop;
-    QAction *popCut = 0;
-    QAction *popCopy = 0;
-    QAction *popPaste = 0;
-    QAction* popDelete = 0;
 
     bool itemsSelected = selectionCount() > 0;
     if (itemsSelected) {
-        popCut = pop.addAction(i18n("Cut"));
-        popCopy = pop.addAction(i18n("Copy"));
+        QAction *a = KStandardAction::cut(this, SLOT(slotEditCut()), &pop);
+        a->setShortcut(QKeySequence::UnknownKey); // shortcuts have no effect in the popup menu
+        pop.addAction(a);
+        a = KStandardAction::copy(this, SLOT(slotEditCopy()), &pop);
+        a->setShortcut(QKeySequence::UnknownKey); // shortcuts have no effect in the popup menu
+        pop.addAction(a);
+    }
+    if (!m_sectionData->copy_list.isEmpty()) {
+        QAction *a = KStandardAction::paste(this, SLOT(slotEditPaste()), &pop);
+        a->setShortcut(QKeySequence::UnknownKey); // shortcuts have no effect in the popup menu
+        pop.addAction(a);
     }
-    if (!m_sectionData->copy_list.isEmpty())
-        popPaste = pop.addAction(i18n("Paste"));
 
     if (itemsSelected) {
         pop.addSeparator();
-        popDelete = pop.addAction(i18n("Delete"));
+        const KGuiItem del = KStandardGuiItem::del();
+        QAction *a = new KAction(del.icon(), del.text(), &pop);
+        a->setToolTip(del.toolTip());
+        connect(a, SIGNAL(activated()), SLOT(slotEditDelete()));
+        pop.addAction(a);
     }
-
-    if (pop.actions().count() > 0) {
-        QAction * ret = pop.exec(e->screenPos());
-        if (ret == popCut)
-            slotEditCut();
-        else if (ret == popCopy)
-            slotEditCopy();
-        else if (ret == popPaste)
-            slotEditPaste(s);
-        else if (ret == popDelete)
-            slotEditDelete();
+    if (!pop.actions().isEmpty()) {
+        pop.exec(e->screenPos());
     }
 }
 
@@ -1185,7 +1182,7 @@ QList<QAction*> KoReportDesigner::actions(QActionGroup* group)
     KoReportPluginManager* manager = KoReportPluginManager::self();
     QList<QAction*> actList = manager->actions();
     
-    KToggleAction *act = new KToggleAction(KIcon("line"), i18n("Line"), group);
+    KToggleAction *act = new KToggleAction(koIcon("line"), i18n("Line"), group);
     act->setObjectName("report:line");
     act->setData(9);
     actList << act;
