@@ -215,7 +215,7 @@ public:
     void sectionMouseReleaseEvent(ReportSceneView *, QMouseEvent * e);
 
     /**
-    @brief Sets the property set for the currenty selected item
+    @brief Sets the property set for the currently selected item
     @param set Property set of item
     */
     void changeSet(KoProperty::Set *);
@@ -292,12 +292,6 @@ private:
 
     KoReportData *m_kordata;
 
-    /**
-    @brief Return a list of supported page formats
-    @return A QStringList of page formats
-    */
-    QStringList pageFormats() const;
-
     /**
     @brief Sets the detail section to the given section
     */
