@@ -31,7 +31,7 @@ public:
 
     KoGenChanges *changes;
     QMap<QString, QString> m_rdfIdMapping; //< This lets the RDF system know old->new xml:id
-    const Soprano::Model* m_rdfModel; //< This is so cut/paste can serialize the relevant RDF to the clipboard
+    QSharedPointer<Soprano::Model> m_rdfModel; //< This is so cut/paste can serialize the relevant RDF to the clipboard
     QMap<int, QString> styleIdToName;
 };
 
@@ -64,12 +64,12 @@ QMap<QString, QString> KoTextSharedSavingData::getRdfIdMapping()
     return d->m_rdfIdMapping;
 }
 
-void KoTextSharedSavingData::setRdfModel(const Soprano::Model* m)
+void KoTextSharedSavingData::setRdfModel(QSharedPointer<Soprano::Model> m)
 {
     d->m_rdfModel = m;
 }
 
-const Soprano::Model* KoTextSharedSavingData::rdfModel() const
+QSharedPointer<Soprano::Model> KoTextSharedSavingData::rdfModel() const
 {
     return d->m_rdfModel;
 }
@@ -83,3 +83,8 @@ QString KoTextSharedSavingData::styleName(int styleId)
 {
     return d->styleIdToName.value(styleId);
 }
+
+QList<QString> KoTextSharedSavingData::styleNames()
+{
+    return d->styleIdToName.values();
+}
