@@ -1,5 +1,5 @@
 /* This file is part of the Calligra project
- * Copyright (C) 2010 KO GmbH <casper.boemann@kogmbh.com>
+ * Copyright (C) 2010 KO GmbH <cbo@kogmbh.com>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -20,7 +20,7 @@
 #define TESTSECTIONSTYLE_H
 
 #include <QObject>
-#include <QtTest/QtTest>
+#include <QtTest>
 
 class TestSectionStyle : public QObject
 {
