@@ -62,6 +62,10 @@ KoDocumentInfo::~KoDocumentInfo()
 
 bool KoDocumentInfo::load(const KoXmlDocument &doc)
 {
+    foreach (const QString tag, m_authorTags) {
+        setActiveAuthorInfo(tag, QString());
+    }
+
     if (!loadAboutInfo(doc.documentElement()))
         return false;
 
@@ -73,6 +77,10 @@ bool KoDocumentInfo::load(const KoXmlDocument &doc)
 
 bool KoDocumentInfo::loadOasis(const KoXmlDocument &metaDoc)
 {
+    foreach (const QString tag, m_authorTags) {
+        setActiveAuthorInfo(tag, QString());
+    }
+
     KoXmlNode t = KoXml::namedItemNS(metaDoc, KoXmlNS::office, "document-meta");
     KoXmlNode office = KoXml::namedItemNS(t, KoXmlNS::office, "meta");
 
