@@ -362,7 +362,9 @@ const KoColorSpace * KoColorSpaceRegistry::colorSpace(const QString &csID, const
 
 const KoColorSpace * KoColorSpaceRegistry::colorSpace(const QString &csID, const KoColorProfile *profile)
 {
-    Q_ASSERT(!csID.isEmpty());
+    if (csID.isEmpty()) {
+        return 0;
+    }
     if (profile) {
         const KoColorSpace *cs = 0;
         if (isCached(csID, profile->name())) {
