@@ -58,7 +58,7 @@ private:
     bool layoutRow(TableIterator *cursor, qreal topBorderWidth, qreal bottomBorderWidth);
     bool layoutMergedCellsNotEnding(TableIterator *cursor, qreal topBorderWidth, qreal bottomBorderWidth, qreal rowBottom);
     QRectF cellBoundingRect(const QTextTableCell &cell) const;
-    void paintCell(QPainter *painter, const KoTextDocumentLayout::PaintContext &context, QTextTableCell tableCell);
+    void paintCell(QPainter *painter, const KoTextDocumentLayout::PaintContext &context, QTextTableCell tableCell, KoTextLayoutArea *frameArea);
     void paintCellBorders(QPainter *painter, const KoTextDocumentLayout::PaintContext &context, QTextTableCell tableCell, bool topRow, QVector<QLineF> *accuBlankBorders);
 
     class Private;
