@@ -83,18 +83,33 @@ public:
     void setZoomMode(KoZoomMode::Mode mode);
 
     /**
-     * Set the zoom and the zoom mode for this zoom Controller.
+     * Set the resolution, zoom, the zoom mode for this zoom Controller.
      * Typically for use just after construction to restore the
      * persistent data.
      *
      * @param mode new zoom mode for the canvas
      * @param zoom (for ZOOM_CONSTANT zoom mode only) new zoom value for
      *             the canvas
+     * @param resolutionX new X resolution for the document
+     * @param resolutionY new Y resolution for the document
      * @param stillPoint (for ZOOM_CONSTANT zoom mode only) the point
      *                   which will not change its position in widget
      *                   during the zooming. It is measured in view
      *                   coordinate system *before* zoom.
      */
+    void setZoom(KoZoomMode::Mode mode, qreal zoom, qreal resolutionX, qreal resolutionY, const QPointF &stillPoint);
+
+
+    /**
+     * Convenience function that changes resolution with
+     * keeping the centering unchanged
+     */
+    void setZoom(KoZoomMode::Mode mode, qreal zoom, qreal resolutionX, qreal resolutionY);
+
+    /**
+     * Convenience function that does not touch the resolution of the
+     * document
+     */
     void setZoom(KoZoomMode::Mode mode, qreal zoom, const QPointF &stillPoint);
 
     /**
