@@ -912,6 +912,18 @@ private:
     QString m_newvalue;
     QString m_oldvalue;
 };
+class KPLATOKERNEL_EXPORT ModifyResourceAutoAllocateCmd : public NamedCommand
+{
+public:
+    ModifyResourceAutoAllocateCmd( Resource *resource, bool value, const QString& name = QString() );
+    void execute();
+    void unexecute();
+
+private:
+    Resource *m_resource;
+    bool m_newvalue;
+    bool m_oldvalue;
+};
 class KPLATOKERNEL_EXPORT ModifyResourceTypeCmd : public NamedCommand
 {
 public:
@@ -1630,6 +1642,18 @@ private:
     int oldvalue, newvalue;
 };
 
+class KPLATOKERNEL_EXPORT ModifyScheduleManagerSchedulingGranularityCmd : public NamedCommand
+{
+public:
+    ModifyScheduleManagerSchedulingGranularityCmd( ScheduleManager &sm, int value, const QString& name = QString() );
+    void execute();
+    void unexecute();
+
+private:
+    ScheduleManager &m_sm;
+    int oldvalue, newvalue;
+};
+
 class KPLATOKERNEL_EXPORT ModifyStandardWorktimeYearCmd : public NamedCommand
 {
 public:
