@@ -45,10 +45,15 @@ namespace KPlato
 
 void CalendarTester::initTestCase()
 {
-    QVERIFY( m_tmp.exists() );
+    QString kdehome = getenv("KDEHOME");
+    QDir d(kdehome);
+    d.mkpath("calendartest");
+    d.cd("calendartest");
 
+    QString dataDir = d.path();
+    qDebug()<<dataDir;
     QFile f;
-    f.setFileName( m_tmp.name() + QLatin1String( "zone.tab" ) );
+    f.setFileName(dataDir + QLatin1String( "/zone.tab" ) );
     f.open(QIODevice::WriteOnly);
     QTextStream fStream(&f);
     fStream << "DE  +5230+01322 Europe/Berlin\n"
@@ -57,28 +62,54 @@ void CalendarTester::initTestCase()
                "GB  +512830-0001845 Europe/London   Great Britain\n"
                "US  +340308-1181434 America/Los_Angeles Pacific Time\n";
     f.close();
-    QDir dir(m_tmp.name());
+    QVERIFY(QFile::exists( dataDir + QLatin1String("/zone.tab")));
+    QDir dir(dataDir);
     QVERIFY(dir.mkdir("Africa"));
-    QFile::copy(QString::fromLatin1(KDESRCDIR) + QLatin1String("/Cairo"), m_tmp.name() + QLatin1String("Africa/Cairo"));
+    QFile::copy(QString::fromLatin1(KDESRCDIR) + QLatin1String("zoneinfo/Cairo"), dataDir + QLatin1String("/Africa/Cairo"));
+    QVERIFY(QFile::exists( dataDir + QLatin1String("/Africa/Cairo")));
     QVERIFY(dir.mkdir("America"));
-    QFile::copy(QString::fromLatin1(KDESRCDIR) + QLatin1String("/Los_Angeles"), m_tmp.name() + QLatin1String("America/Los_Angeles"));
+    QFile::copy(QString::fromLatin1(KDESRCDIR) + QLatin1String("zoneinfo/Los_Angeles"), dataDir + QLatin1String("/America/Los_Angeles"));
+    QVERIFY(QFile::exists( dataDir + QLatin1String("/America/Los_Angeles")));
     QVERIFY(dir.mkdir("Europe"));
-    QFile::copy(QString::fromLatin1(KDESRCDIR) + QLatin1String("/Berlin"), m_tmp.name() + QLatin1String("Europe/Berlin"));
-    QFile::copy(QString::fromLatin1(KDESRCDIR) + QLatin1String("/London"), m_tmp.name() + QLatin1String("Europe/London"));
-    QFile::copy(QString::fromLatin1(KDESRCDIR) + QLatin1String("/Paris"), m_tmp.name() + QLatin1String("Europe/Paris"));
+    QFile::copy(QString::fromLatin1(KDESRCDIR) + QLatin1String("zoneinfo/Berlin"), dataDir + QLatin1String("/Europe/Berlin"));
+    QVERIFY(QFile::exists( dataDir + QLatin1String("/Europe/Berlin")));
+    QFile::copy(QString::fromLatin1(KDESRCDIR) + QLatin1String("zoneinfo/London"),dataDir + QLatin1String("/Europe/London"));
+    QVERIFY(QFile::exists( dataDir + QLatin1String("/Europe/London")));
+    QFile::copy(QString::fromLatin1(KDESRCDIR) + QLatin1String("zoneinfo/Paris"), dataDir + QLatin1String("/Europe/Paris"));
+    QVERIFY(QFile::exists( dataDir + QLatin1String("/Europe/Paris")));
 
     // NOTE: QTEST_KDEMAIN_CORE puts the config file in QDir::homePath() + "/.kde-unit-test"
     //       and hence, this is common to all unit tests
     KConfig config("ktimezonedrc");
     KConfigGroup group(&config, "TimeZones");
-    group.writeEntry("ZoneinfoDir", m_tmp.name());
-    group.writeEntry("Zonetab", m_tmp.name() + QString::fromLatin1("zone.tab"));
+    group.writeEntry("ZoneinfoDir", dataDir);
+    group.writeEntry("Zonetab", dataDir + QString::fromLatin1("/zone.tab"));
     group.writeEntry("LocalZone", QString::fromLatin1("Europe/Berlin"));
     config.sync();
 }
 
 void CalendarTester::cleanupTestCase()
 {
+    QString kdehome = getenv("KDEHOME");
+    removeDir( kdehome + "/calendartest/Africa" );
+    removeDir( kdehome + "/calendartest/America" );
+    removeDir( kdehome + "/calendartest/Europe" );
+    removeDir( kdehome + "/calendartest" );
+    removeDir( kdehome + "/share/config" );
+    QDir().rmpath(kdehome +"/share/calendartest");
+}
+
+void CalendarTester::removeDir(const QString &dir)
+{
+    QDir local(dir);
+    foreach(const QString &file, local.entryList(QDir::Files))
+        if(!local.remove(file))
+            qWarning("%s: removing failed", qPrintable( file ));
+        QCOMPARE((int)local.entryList(QDir::Files).count(), 0);
+    local.cdUp();
+    QString subd = dir;
+    subd.remove(QRegExp("^.*/"));
+    local.rmpath(subd);
 }
 
 void CalendarTester::testSingleDay() {
@@ -192,6 +223,7 @@ void CalendarTester::testTimezone()
 
     // local zone: Europe/Berlin ( 1 hours from London )
     KTimeZone lo = KSystemTimeZones::zone("Europe/London");
+    QVERIFY( lo.isValid() );
     KDateTime dt1 = KDateTime( wdate, t1, lo ).addSecs( -2 * 3600 );
     KDateTime dt2 = KDateTime( wdate, t2, lo ).addSecs( 0 * 3600 );
 
@@ -205,6 +237,7 @@ void CalendarTester::testTimezone()
 
     // local zone: Europe/Berlin ( 9 hours from America/Los_Angeles )
     KTimeZone la = KSystemTimeZones::zone("America/Los_Angeles");
+    QVERIFY( la.isValid() );
     KDateTime dt3 = KDateTime( wdate, t1, la ).addSecs( -10 * 3600 );
     KDateTime dt4 = KDateTime( wdate, t2, la ).addSecs( -8 * 3600 );
 
