@@ -1,5 +1,5 @@
 /* This file is part of the KDE project
-  Copyright (C) 2007 Dag Andersen <danders@get2net.dk>
+  Copyright (C) 2007, 2012 Dag Andersen <danders@get2net.dk>
 
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
@@ -28,6 +28,7 @@
 #include "kptproject.h"
 #include "kpttask.h"
 #include "kptnodeitemmodel.h"
+#include "kptdebug.h"
 
 #include <QAbstractItemModel>
 #include <QMimeData>
@@ -36,6 +37,7 @@
 #include <kglobal.h>
 #include <klocale.h>
 
+
 namespace KPlato
 {
 
@@ -73,37 +75,52 @@ TaskStatusItemModel::~TaskStatusItemModel()
     
 void TaskStatusItemModel::slotAboutToBeReset()
 {
-    kDebug();
+    kDebug(planDbg());
     clear();
 }
 
 void TaskStatusItemModel::slotReset()
 {
-    kDebug();
+    kDebug(planDbg());
     refresh();
 }
 
 void TaskStatusItemModel::slotNodeToBeInserted( Node *, int )
 {
-    //kDebug()<<node->name();
+    //kDebug(planDbg())<<node->name();
     clear();
 }
 
 void TaskStatusItemModel::slotNodeInserted( Node * /*node*/ )
 {
-    //kDebug()<<node->getParent->name()<<"-->"<<node->name();
+    //kDebug(planDbg())<<node->getParent->name()<<"-->"<<node->name();
     refresh();
 }
 
 void TaskStatusItemModel::slotNodeToBeRemoved( Node * /*node*/ )
 {
-    //kDebug()<<node->name();
+    //kDebug(planDbg())<<node->name();
     clear();
 }
 
 void TaskStatusItemModel::slotNodeRemoved( Node * /*node*/ )
 {
-    //kDebug()<<node->name();
+    //kDebug(planDbg())<<node->name();
+    refresh();
+}
+
+void TaskStatusItemModel::slotNodeToBeMoved(Node *node, int pos, Node *newParent, int newPos)
+{
+    Q_UNUSED( node );
+    Q_UNUSED( pos );
+    Q_UNUSED( newParent );
+    Q_UNUSED( newPos );
+    clear();
+}
+
+void TaskStatusItemModel::slotNodeMoved( Node * /*node*/ )
+{
+    //kDebug(planDbg())<<node->name();
     refresh();
 }
 
@@ -116,11 +133,11 @@ void TaskStatusItemModel::setProject( Project *project )
         disconnect( m_project, SIGNAL( nodeChanged( Node* ) ), this, SLOT( slotNodeChanged( Node* ) ) );
         disconnect( m_project, SIGNAL( nodeToBeAdded( Node*, int ) ), this, SLOT( slotNodeToBeInserted(  Node*, int ) ) );
         disconnect( m_project, SIGNAL( nodeToBeRemoved( Node* ) ), this, SLOT( slotNodeToBeRemoved( Node* ) ) );
-        disconnect( m_project, SIGNAL( nodeToBeMoved( Node* ) ), this, SLOT( slotLayoutToBeChanged() ) );
+        disconnect(m_project, SIGNAL(nodeToBeMoved(Node*,int,Node*,int)), this, SLOT(slotNodeToBeMoved(Node*,int,Node*,int)));
     
         disconnect( m_project, SIGNAL( nodeAdded( Node* ) ), this, SLOT( slotNodeInserted( Node* ) ) );
         disconnect( m_project, SIGNAL( nodeRemoved( Node* ) ), this, SLOT( slotNodeRemoved( Node* ) ) );
-        disconnect( m_project, SIGNAL( nodeMoved( Node* ) ), this, SLOT( slotLayoutChanged() ) );
+        disconnect(m_project, SIGNAL(nodeMoved(Node*)), this, SLOT(slotNodeMoved(Node*)));
     }
     m_project = project;
     m_nodemodel.setProject( project );
@@ -130,12 +147,12 @@ void TaskStatusItemModel::setProject( Project *project )
         connect( m_project, SIGNAL( nodeChanged( Node* ) ), this, SLOT( slotNodeChanged( Node* ) ) );
         connect( m_project, SIGNAL( nodeToBeAdded( Node*, int ) ), this, SLOT( slotNodeToBeInserted(  Node*, int ) ) );
         connect( m_project, SIGNAL( nodeToBeRemoved( Node* ) ), this, SLOT( slotNodeToBeRemoved( Node* ) ) );
-        connect( m_project, SIGNAL( nodeToBeMoved( Node* ) ), this, SLOT( slotLayoutToBeChanged() ) );
-    
+        connect(m_project, SIGNAL(nodeToBeMoved(Node*,int,Node*,int)), this, SLOT(slotNodeToBeMoved(Node*,int,Node*,int)));
+
         connect( m_project, SIGNAL( nodeAdded( Node* ) ), this, SLOT( slotNodeInserted( Node* ) ) );
         connect( m_project, SIGNAL( nodeRemoved( Node* ) ), this, SLOT( slotNodeRemoved( Node* ) ) );
-        connect( m_project, SIGNAL( nodeMoved( Node* ) ), this, SLOT( slotLayoutChanged() ) );
-        
+        connect(m_project, SIGNAL(nodeMoved(Node*)), this, SLOT(slotNodeMoved(Node*)));
+
     }
     reset();
 }
@@ -146,6 +163,7 @@ void TaskStatusItemModel::setScheduleManager( ScheduleManager *sm )
     if ( m_nodemodel.manager() ) {
     }
     m_nodemodel.setManager( sm );
+    ItemModelBase::setScheduleManager( sm );
     if ( sm ) {
     }
     reset();
@@ -160,7 +178,7 @@ void TaskStatusItemModel::clear()
             //FIXME: gives error msg:
             // Can't select indexes from different model or with different parents
             QModelIndex i = index( l );
-            kDebug()<<i<<0<<c-1;
+            kDebug(planDbg())<<i<<0<<c-1;
             beginRemoveRows( i, 0, c-1 );
             l->clear();
             endRemoveRows();
@@ -224,7 +242,7 @@ void TaskStatusItemModel::refresh()
     foreach ( NodeMap *l, m_top ) {
         int c = l->count();
         if ( c > 0 ) {
-            kDebug()<<index(l)<<0<<c-1;
+            kDebug(planDbg())<<index(l)<<0<<c-1;
             beginInsertRows( index( l ), 0, c-1 );
             endInsertRows();
         }
@@ -281,7 +299,7 @@ QModelIndex TaskStatusItemModel::parent( const QModelIndex &index ) const
     if ( !index.isValid() ) {
         return QModelIndex();
     }
-    //kDebug()<<index.internalPointer()<<":"<<index.row()<<","<<index.column();
+    //kDebug(planDbg())<<index.internalPointer()<<":"<<index.row()<<","<<index.column();
     int row = m_top.indexOf( static_cast<NodeMap*>( index.internalPointer() ) );
     if ( row != -1 ) {
         return QModelIndex(); // top level has no parent
@@ -305,7 +323,7 @@ QModelIndex TaskStatusItemModel::parent( const QModelIndex &index ) const
 
 QModelIndex TaskStatusItemModel::index( int row, int column, const QModelIndex &parent ) const
 {
-    //kDebug()<<row<<column<<parent;
+    //kDebug(planDbg())<<row<<column<<parent;
     if ( m_project == 0 || column < 0 || column >= columnCount() || row < 0 ) {
         return QModelIndex();
     }
@@ -394,7 +412,7 @@ bool TaskStatusItemModel::setCompletion( Node *node, const QVariant &value, int
         if ( c.entrymode() == Completion::EnterCompleted ) {
             Duration planned = static_cast<Task*>( node )->plannedEffort( m_nodemodel.id() );
             Duration actual = ( planned * value.toInt() ) / 100;
-            kDebug()<<planned.toString()<<value.toInt()<<actual.toString();
+            kDebug(planDbg())<<planned.toString()<<value.toInt()<<actual.toString();
             NamedCommand *cmd = new ModifyCompletionActualEffortCmd( c, date, actual );
             cmd->execute();
             m->addCommand( cmd );
@@ -606,15 +624,15 @@ int TaskStatusItemModel::columnCount( const QModelIndex & ) const
 int TaskStatusItemModel::rowCount( const QModelIndex &parent ) const
 {
     if ( ! parent.isValid() ) {
-        //kDebug()<<"top="<<m_top.count()<<m_top;
+        //kDebug(planDbg())<<"top="<<m_top.count()<<m_top;
         return m_top.count();
     }
     NodeMap *l = list( parent );
     if ( l ) {
-        //kDebug()<<"list"<<parent.row()<<":"<<l->count()<<l<<m_topNames.value( parent.row() );
+        //kDebug(planDbg())<<"list"<<parent.row()<<":"<<l->count()<<l<<m_topNames.value( parent.row() );
         return l->count();
     }
-    //kDebug()<<"node"<<parent.row();
+    //kDebug(planDbg())<<"node"<<parent.row();
     return 0; // nodes don't have children
 }
 
@@ -637,7 +655,7 @@ QMimeData *TaskStatusItemModel::mimeData( const QModelIndexList & indexes ) cons
     QList<int> rows;
     foreach (const QModelIndex &index, indexes) {
         if ( index.isValid() && !rows.contains( index.row() ) ) {
-            //kDebug()<<index.row();
+            //kDebug(planDbg())<<index.row();
             Node *n = node( index );
             if ( n ) {
                 rows << index.row();
@@ -685,7 +703,7 @@ Node *TaskStatusItemModel::node( const QModelIndex &index ) const
 
 void TaskStatusItemModel::slotNodeChanged( Node *node )
 {
-    kDebug();
+    kDebug(planDbg());
     if ( node == 0 || node->type() == Node::Type_Project ) {
         return;
     }
@@ -707,7 +725,7 @@ void TaskStatusItemModel::slotNodeChanged( Node *node )
 
 void TaskStatusItemModel::slotWbsDefinitionChanged()
 {
-    kDebug();
+    kDebug(planDbg());
     foreach ( NodeMap *l, m_top ) {
         for ( int row = 0; row < l->count(); ++row ) {
             emit dataChanged( createIndex( row, NodeModel::NodeWBSCode, l->values().value( row ) ), createIndex( row, NodeModel::NodeWBSCode, l->values().value( row ) ) );
@@ -717,11 +735,31 @@ void TaskStatusItemModel::slotWbsDefinitionChanged()
 
 void TaskStatusItemModel::slotLayoutChanged()
 {
-    //kDebug()<<node->name();
+    //kDebug(planDbg())<<node->name();
     emit layoutAboutToBeChanged();
     emit layoutChanged();
 }
 
+int TaskStatusItemModel::sortRole( int column ) const
+{
+    switch ( column ) {
+        case NodeModel::NodeStartTime:
+        case NodeModel::NodeEndTime:
+        case NodeModel::NodeActualStart:
+        case NodeModel::NodeActualFinish:
+        case NodeModel::NodeEarlyStart:
+        case NodeModel::NodeEarlyFinish:
+        case NodeModel::NodeLateStart:
+        case NodeModel::NodeLateFinish:
+        case NodeModel::NodeConstraintStart:
+        case NodeModel::NodeConstraintEnd:
+            return Qt::EditRole;
+        default:
+            break;
+    }
+    return Qt::DisplayRole;
+}
+
 } // namespace KPlato
 
 #include "kpttaskstatusmodel.moc"
