@@ -29,8 +29,11 @@
 #include "kptworkpackagesendpanel.h"
 #include "kptdatetime.h"
 #include "kptdebug.h"
+#include "kptresourcemodel.h"
+#include "kptresourceallocationmodel.h"
 
 #include <KoDocument.h>
+#include <KoIcon.h>
 
 #include <QItemSelectionModel>
 #include <QModelIndex>
@@ -38,8 +41,8 @@
 #include <QWidget>
 #include <QMenu>
 #include <QDragMoveEvent>
+#include <QDockWidget>
 
-#include <kicon.h>
 #include <kaction.h>
 #include <kactionmenu.h>
 #include <kglobal.h>
@@ -228,6 +231,7 @@ void TaskEditorTreeView::slotDropAllowed( const QModelIndex &index, int dropIndi
     if ( pr ) {
         idx = pr->mapToSource( index );
     }
+    event->ignore();
     if ( baseModel()->dropAllowed( idx, dropIndicatorPosition, event->mimeData() ) ) {
         event->accept();
     }
@@ -264,6 +268,7 @@ void NodeTreeView::slotDropAllowed( const QModelIndex &index, int dropIndicatorP
     if ( pr ) {
         idx = pr->mapToSource( index );
     }
+    event->ignore();
     if ( baseModel()->dropAllowed( idx, dropIndicatorPosition, event->mimeData() ) ) {
         event->accept();
     }
@@ -271,8 +276,8 @@ void NodeTreeView::slotDropAllowed( const QModelIndex &index, int dropIndicatorP
 
 
 //-----------------------------------
-TaskEditor::TaskEditor( KoDocument *part, QWidget *parent )
-    : ViewBase( part, parent )
+TaskEditor::TaskEditor(KoPart *part, KoDocument *doc, QWidget *parent)
+    : ViewBase(part, doc, parent )
 {
     kDebug(planDbg())<<"----------------- Create TaskEditor ----------------------";
     QVBoxLayout * l = new QVBoxLayout( this );
@@ -284,7 +289,7 @@ TaskEditor::TaskEditor( KoDocument *part, QWidget *parent )
 
     m_view->setEditTriggers( m_view->editTriggers() | QAbstractItemView::EditKeyPressed );
 
-    m_view->setDragDropMode( QAbstractItemView::InternalMove );
+    m_view->setDragDropMode( QAbstractItemView::DragDrop );
     m_view->setDropIndicatorShown( true );
     m_view->setDragEnabled ( true );
     m_view->setAcceptDrops( true );
@@ -327,7 +332,7 @@ TaskEditor::TaskEditor( KoDocument *part, QWidget *parent )
     m_view->masterView()->setDefaultColumns( QList<int>() << NodeModel::NodeName );
     m_view->slaveView()->setDefaultColumns( show );
 
-    connect( model(), SIGNAL( executeCommand( KUndo2Command* ) ), part, SLOT( addCommand( KUndo2Command* ) ) );
+    connect( model(), SIGNAL( executeCommand( KUndo2Command* ) ), doc, SLOT( addCommand( KUndo2Command* ) ) );
 
     connect( m_view, SIGNAL( currentChanged( const QModelIndex &, const QModelIndex & ) ), this, SLOT ( slotCurrentChanged( const QModelIndex &, const QModelIndex & ) ) );
 
@@ -338,6 +343,7 @@ TaskEditor::TaskEditor( KoDocument *part, QWidget *parent )
     connect( m_view, SIGNAL( headerContextMenuRequested( const QPoint& ) ), SLOT( slotHeaderContextMenuRequested( const QPoint& ) ) );
 
     connect(baseModel(), SIGNAL(projectShownChanged(bool)), SLOT(slotProjectShown(bool)));
+    connect(model(), SIGNAL(rowsMoved(const QModelIndex&, int, int, const QModelIndex&, int)), this, SLOT(slotEnableActions()));
 }
 
 void TaskEditor::slotProjectShown( bool on )
@@ -365,13 +371,87 @@ void TaskEditor::updateReadWrite( bool rw )
     ViewBase::updateReadWrite( rw );
 }
 
-void TaskEditor::draw( Project &project )
+void TaskEditor::setProject( Project *project )
 {
-    m_view->setProject( &project );
+    kDebug(planDbg())<<project;
+    m_view->setProject( project );
+    ViewBase::setProject( project );
 }
 
-void TaskEditor::draw()
+void TaskEditor::createDockers()
 {
+    // Add dockers
+    DockWidget *ds = new DockWidget( this, "Allocations", i18nc( "@title resource allocations", "Allocations" ) );
+    QTreeView *x = new QTreeView( ds );
+    AllocatedResourceItemModel *m1 = new AllocatedResourceItemModel( x );
+    x->setModel( m1 );
+    m1->setProject( project() );
+//     x->setHeaderHidden( true );
+    x->setSelectionBehavior( QAbstractItemView::SelectRows );
+    x->setSelectionMode( QAbstractItemView::ExtendedSelection );
+    x->expandAll();
+    x->resizeColumnToContents( 0 );
+    x->setDragDropMode( QAbstractItemView::DragOnly );
+    x->setDragEnabled ( true );
+    ds->setWidget( x );
+    connect(this, SIGNAL(projectChanged(Project*)), m1, SLOT(setProject(Project*)));
+    connect(this, SIGNAL(taskSelected(Task*)), m1, SLOT(setTask(Task*)));
+    connect(m1, SIGNAL(expandAll()), x, SLOT(expandAll()));
+    connect(m1, SIGNAL(resizeColumnToContents(int)), x, SLOT(resizeColumnToContents(int)));
+    addDocker( ds );
+
+    ds = new DockWidget( this, "Resources", i18nc( "@title", "Resources" ) );
+    ds->setToolTip( i18nc( "@info:tooltip",
+                          "Drag resources into the Task Editor"
+                          " and drop into the allocations- or responsible column" ) );
+    QTreeView *e = new QTreeView( ds );
+    ResourceItemModel *m = new ResourceItemModel( e );
+    e->setModel( m );
+    m->setProject( project() );
+    m->setReadWrite( isReadWrite() );
+    QList<int> show; show << ResourceModel::ResourceName;
+    for ( int i = m->columnCount() - 1; i >= 0; --i ) {
+        e->setColumnHidden( i, ! show.contains( i ) );
+    }
+    e->setHeaderHidden( true );
+    e->setSelectionBehavior( QAbstractItemView::SelectRows );
+    e->setSelectionMode( QAbstractItemView::ExtendedSelection );
+    e->expandAll();
+    e->resizeColumnToContents( ResourceModel::ResourceName );
+    e->setDragDropMode( QAbstractItemView::DragOnly );
+    e->setDragEnabled ( true );
+    ds->setWidget( e );
+    connect(this, SIGNAL(projectChanged(Project*)), m, SLOT(setProject(Project*)));
+    connect(this, SIGNAL(readWriteChanged(bool)), m, SLOT(setReadWrite(bool)));
+    connect(m, SIGNAL(executeCommand(KUndo2Command*)), part(), SLOT(addCommand(KUndo2Command*)));
+    addDocker( ds );
+
+    {
+        ds = new DockWidget( this, "Taskmodules", i18nc( "@title", "Task Modules" ) );
+        ds->setToolTip( i18nc( "@info:tooltip", "Drag a task module into the <emphasis>Task Editor</emphasis> to add it to the project" ) );
+        ds->setLocation( Qt::LeftDockWidgetArea );
+        e = new QTreeView( ds );
+        TaskModuleModel *m = new TaskModuleModel( e );
+        e->setModel( m );
+        e->setHeaderHidden( true );
+        e->setRootIsDecorated( false );
+        e->setSelectionBehavior( QAbstractItemView::SelectRows );
+        e->setSelectionMode( QAbstractItemView::SingleSelection );
+//         e->resizeColumnToContents( 0 );
+        e->setDragDropMode( QAbstractItemView::DragDrop );
+        e->setAcceptDrops( true );
+        e->setDragEnabled ( true );
+        ds->setWidget( e );
+        connect(this, SIGNAL(loadTaskModules(const QStringList&)), m, SLOT(loadTaskModules(const QStringList&)));
+        connect(m, SIGNAL(saveTaskModule(const KUrl&, Project*)), this, SIGNAL(saveTaskModule(const KUrl&, Project*)));
+        connect(m, SIGNAL(removeTaskModule(const KUrl&)), this, SIGNAL(removeTaskModule(const KUrl&)));
+        addDocker( ds );
+    }
+}
+
+void TaskEditor::setTaskModules(const QStringList& files)
+{
+    emit loadTaskModules( files );
 }
 
 void TaskEditor::setGuiActive( bool activate )
@@ -384,7 +464,7 @@ void TaskEditor::setGuiActive( bool activate )
     }
 }
 
-void TaskEditor::slotCurrentChanged(  const QModelIndex &curr, const QModelIndex & )
+void TaskEditor::slotCurrentChanged( const QModelIndex &curr, const QModelIndex & )
 {
     kDebug(planDbg())<<curr.row()<<","<<curr.column();
     slotEnableActions();
@@ -394,6 +474,7 @@ void TaskEditor::slotSelectionChanged( const QModelIndexList list)
 {
     kDebug(planDbg())<<list.count();
     slotEnableActions();
+    emit taskSelected( dynamic_cast<Task*>( selectedNode() ) );
 }
 
 QModelIndexList TaskEditor::selectedRows() const
@@ -614,7 +695,7 @@ void TaskEditor::setupGui()
 {
     QString name = "taskeditor_add_list";
 
-    menuAddTask = new KActionMenu( KIcon( "view-task-add" ), i18n( "Add Task" ), this );
+    menuAddTask = new KActionMenu(koIcon("view-task-add"), i18n("Add Task"), this);
     actionCollection()->addAction("add_task", menuAddTask );
     connect( menuAddTask, SIGNAL( triggered( bool ) ), SLOT( slotAddTask() ) );
     addAction( name, menuAddTask );
@@ -630,7 +711,7 @@ void TaskEditor::setupGui()
     menuAddTask->addAction( actionAddMilestone );
 
 
-    menuAddSubTask = new KActionMenu( KIcon( "view-task-child-add" ), i18n( "Add Sub-Task" ), this );
+    menuAddSubTask = new KActionMenu(koIcon("view-task-child-add"), i18n("Add Sub-Task"), this);
     actionCollection()->addAction("add_subtask", menuAddTask );
     connect( menuAddSubTask, SIGNAL( triggered( bool ) ), SLOT( slotAddSubtask() ) );
     addAction( name, menuAddSubTask );
@@ -645,7 +726,7 @@ void TaskEditor::setupGui()
     connect( actionAddSubMilestone, SIGNAL( triggered( bool ) ), SLOT( slotAddSubMilestone() ) );
     menuAddSubTask->addAction( actionAddSubMilestone );
 
-    actionDeleteTask  = new KAction(KIcon( "edit-delete" ), i18nc( "@action", "Delete" ), this);
+    actionDeleteTask  = new KAction(koIcon("edit-delete"), i18nc("@action", "Delete"), this);
     actionDeleteTask->setShortcut( KShortcut( Qt::Key_Delete ) );
     actionCollection()->addAction("delete_task", actionDeleteTask );
     connect( actionDeleteTask, SIGNAL( triggered( bool ) ), SLOT( slotDeleteTask() ) );
@@ -653,22 +734,22 @@ void TaskEditor::setupGui()
 
 
     name = "taskeditor_move_list";
-    actionIndentTask  = new KAction(KIcon("format-indent-more"), i18n("Indent Task"), this);
+    actionIndentTask  = new KAction(koIcon("format-indent-more"), i18n("Indent Task"), this);
     actionCollection()->addAction("indent_task", actionIndentTask );
     connect(actionIndentTask, SIGNAL(triggered(bool) ), SLOT(slotIndentTask()));
     addAction( name, actionIndentTask );
 
-    actionUnindentTask  = new KAction(KIcon("format-indent-less"), i18n("Unindent Task"), this);
+    actionUnindentTask  = new KAction(koIcon("format-indent-less"), i18n("Unindent Task"), this);
     actionCollection()->addAction("unindent_task", actionUnindentTask );
     connect(actionUnindentTask, SIGNAL(triggered(bool) ), SLOT(slotUnindentTask()));
     addAction( name, actionUnindentTask );
 
-    actionMoveTaskUp  = new KAction(KIcon("arrow-up"), i18n("Move Up"), this);
+    actionMoveTaskUp  = new KAction(koIcon("arrow-up"), i18n("Move Up"), this);
     actionCollection()->addAction("move_task_up", actionMoveTaskUp );
     connect(actionMoveTaskUp, SIGNAL(triggered(bool) ), SLOT(slotMoveTaskUp()));
     addAction( name, actionMoveTaskUp );
 
-    actionMoveTaskDown  = new KAction(KIcon("arrow-down"), i18n("Move Down"), this);
+    actionMoveTaskDown  = new KAction(koIcon("arrow-down"), i18n("Move Down"), this);
     actionCollection()->addAction("move_task_down", actionMoveTaskDown );
     connect(actionMoveTaskDown, SIGNAL(triggered(bool) ), SLOT(slotMoveTaskDown()));
     addAction( name, actionMoveTaskDown );
@@ -682,6 +763,8 @@ void TaskEditor::setupGui()
     addContextAction( m_view->actionSplitView() );
 
     createOptionAction();
+
+    createDockers();
 }
 
 void TaskEditor::slotSplitView()
@@ -695,7 +778,8 @@ void TaskEditor::slotSplitView()
 void TaskEditor::slotOptions()
 {
     kDebug(planDbg());
-    SplitItemViewSettupDialog *dlg = new SplitItemViewSettupDialog( m_view, this );
+    SplitItemViewSettupDialog *dlg = new SplitItemViewSettupDialog( this, m_view, this );
+    dlg->addPrintingOptions();
     connect(dlg, SIGNAL(finished(int)), SLOT(slotOptionsFinished(int)));
     dlg->show();
     dlg->raise();
@@ -900,8 +984,8 @@ KoPrintJob *TaskEditor::createPrintJob()
 
 
 //-----------------------------------
-TaskView::TaskView( KoDocument *part, QWidget *parent )
-    : ViewBase( part, parent )
+TaskView::TaskView(KoPart *part, KoDocument *doc, QWidget *parent)
+    : ViewBase(part, doc, parent)
 {
     QVBoxLayout * l = new QVBoxLayout( this );
     l->setMargin( 0 );
@@ -966,7 +1050,7 @@ TaskView::TaskView( KoDocument *part, QWidget *parent )
     m_view->masterView()->setDefaultColumns( QList<int>() << 0 );
     m_view->slaveView()->setDefaultColumns( show );
 
-    connect( m_view->baseModel(), SIGNAL( executeCommand( KUndo2Command* ) ), part, SLOT( addCommand( KUndo2Command* ) ) );
+    connect( m_view->baseModel(), SIGNAL( executeCommand( KUndo2Command* ) ), doc, SLOT( addCommand( KUndo2Command* ) ) );
 
     connect( m_view, SIGNAL( currentChanged( const QModelIndex &, const QModelIndex & ) ), this, SLOT ( slotCurrentChanged( const QModelIndex &, const QModelIndex & ) ) );
 
@@ -1120,7 +1204,8 @@ void TaskView::slotSplitView()
 void TaskView::slotOptions()
 {
     kDebug(planDbg());
-    SplitItemViewSettupDialog *dlg = new SplitItemViewSettupDialog( m_view, this );
+    SplitItemViewSettupDialog *dlg = new SplitItemViewSettupDialog( this, m_view, this );
+    dlg->addPrintingOptions();
     connect(dlg, SIGNAL(finished(int)), SLOT(slotOptionsFinished(int)));
     dlg->show();
     dlg->raise();
@@ -1149,65 +1234,50 @@ KoPrintJob *TaskView::createPrintJob()
 }
 
 //---------------------------------
-GeneralNodeTreeView::GeneralNodeTreeView( QWidget *parent )
+WorkPackageTreeView::WorkPackageTreeView( QWidget *parent )
     : DoubleTreeViewBase( parent )
 {
-    GeneralNodeItemModel *m = new GeneralNodeItemModel( this );
+    kDebug(planDbg())<<"----------"<<this<<"----------";
+    m = new WorkPackageProxyModel( this );
     setModel( m );
     //setSelectionBehavior( QAbstractItemView::SelectItems );
     setSelectionMode( QAbstractItemView::ExtendedSelection );
     setSelectionBehavior( QAbstractItemView::SelectRows );
 
-    createItemDelegates( m );
+    createItemDelegates( baseModel() );
+
+    setSortingEnabled( true );
+    sortByColumn( NodeModel::NodeWBSCode, Qt::AscendingOrder );
 
     connect( this, SIGNAL( dropAllowed( const QModelIndex&, int, QDragMoveEvent* ) ), SLOT(slotDropAllowed( const QModelIndex&, int, QDragMoveEvent* ) ) );
 }
 
-void GeneralNodeTreeView::setModus( int mode )
+NodeItemModel *WorkPackageTreeView::baseModel() const
 {
-    baseModel()->setModus( mode );
+    return m->baseModel();
 }
 
-GeneralNodeItemModel *GeneralNodeTreeView::baseModel() const
+void WorkPackageTreeView::slotDropAllowed( const QModelIndex &index, int dropIndicatorPosition, QDragMoveEvent *event )
 {
-    NodeSortFilterProxyModel *pr = proxyModel();
-    if ( pr ) {
-        return static_cast<GeneralNodeItemModel*>( pr->sourceModel() );
-    }
-    return static_cast<GeneralNodeItemModel*>( model() );
-}
-
-void GeneralNodeTreeView::slotDropAllowed( const QModelIndex &index, int dropIndicatorPosition, QDragMoveEvent *event )
-{
-    QModelIndex idx = index;
+/*    QModelIndex idx = index;
     NodeSortFilterProxyModel *pr = proxyModel();
     if ( pr ) {
         idx = pr->mapToSource( index );
     }
+    event->ignore();
     if ( baseModel()->dropAllowed( idx, dropIndicatorPosition, event->mimeData() ) ) {
         event->accept();
-    }
+    }*/
 }
 
 //--------------------------------
-TaskWorkPackageView::TaskWorkPackageView( KoDocument *part, QWidget *parent )
-    : ViewBase( part, parent ),
+TaskWorkPackageView::TaskWorkPackageView(KoPart *part, KoDocument *doc, QWidget *parent)
+    : ViewBase(part, doc, parent ),
     m_cmd( 0 )
 {
     QVBoxLayout * l = new QVBoxLayout( this );
     l->setMargin( 0 );
-    m_view = new GeneralNodeTreeView( this );
-    m_view->setModus( GeneralNodeItemModel::Flat | GeneralNodeItemModel::WorkPackage );
-    NodeSortFilterProxyModel *p = new NodeSortFilterProxyModel( m_view->baseModel(), m_view, false );
-    m_view->setModel( p );
-
-    m_view->setSortingEnabled( true );
-    m_view->sortByColumn( NodeModel::NodeWBSCode, Qt::AscendingOrder );
-
-    // match empty string or Type_Task
-    p->setFilterRegExp( QRegExp( QString( "^$|%1").arg( Node::Type_Task ) ) );
-    p->setFilterRole( Qt::EditRole );
-    p->setFilterKeyColumn( NodeModel::NodeType );
+    m_view = new WorkPackageTreeView( this );
 
     l->addWidget( m_view );
     setupGui();
@@ -1263,7 +1333,7 @@ TaskWorkPackageView::TaskWorkPackageView( KoDocument *part, QWidget *parent )
     m_view->masterView()->setDefaultColumns( QList<int>() << 0 );
     m_view->slaveView()->setDefaultColumns( show );
 
-    connect( m_view->baseModel(), SIGNAL( executeCommand( KUndo2Command* ) ), part, SLOT( addCommand( KUndo2Command* ) ) );
+    connect( m_view->baseModel(), SIGNAL( executeCommand( KUndo2Command* ) ), doc, SLOT( addCommand( KUndo2Command* ) ) );
 
     connect( m_view, SIGNAL( currentChanged( const QModelIndex &, const QModelIndex & ) ), this, SLOT ( slotCurrentChanged( const QModelIndex &, const QModelIndex & ) ) );
 
@@ -1284,7 +1354,7 @@ void TaskWorkPackageView::setProject( Project *project )
     m_view->setProject( project );
 }
 
-NodeSortFilterProxyModel *TaskWorkPackageView::proxyModel() const
+WorkPackageProxyModel *TaskWorkPackageView::proxyModel() const
 {
     return m_view->proxyModel();
 }
@@ -1335,7 +1405,7 @@ QList<Node*> TaskWorkPackageView::selectedNodes() const {
         return lst;
     }
     foreach ( const QModelIndex &i, sm->selectedRows() ) {
-        Node * n = m_view->baseModel()->node( proxyModel()->mapToSource( i ) );
+        Node * n = proxyModel()->taskFromIndex( i );
         if ( n != 0 && n->type() != Node::Type_Project ) {
             lst.append( n );
         }
@@ -1353,7 +1423,7 @@ Node *TaskWorkPackageView::selectedNode() const
 }
 
 Node *TaskWorkPackageView::currentNode() const {
-    Node * n = m_view->baseModel()->node( proxyModel()->mapToSource( m_view->selectionModel()->currentIndex() ) );
+    Node * n = proxyModel()->taskFromIndex( m_view->selectionModel()->currentIndex() );
     if ( n == 0 || n->type() == Node::Type_Project ) {
         return 0;
     }
@@ -1363,7 +1433,7 @@ Node *TaskWorkPackageView::currentNode() const {
 void TaskWorkPackageView::slotContextMenuRequested( const QModelIndex& index, const QPoint& pos )
 {
     QString name;
-    Node *node = m_view->baseModel()->node( proxyModel()->mapToSource( index ) );
+    Node *node = proxyModel()->taskFromIndex( index );
     if ( node ) {
         switch ( node->type() ) {
             case Node::Type_Task:
@@ -1409,7 +1479,7 @@ void TaskWorkPackageView::setupGui()
 //    KActionCollection *coll = actionCollection();
 
     QString name = "workpackage_list";
-    actionMailWorkpackage  = new KAction(KIcon( "mail-send" ), i18n("Send..."), this);
+    actionMailWorkpackage  = new KAction(koIcon("mail-send"), i18n("Send..."), this);
     actionMailWorkpackage->setShortcut( KShortcut( Qt::CTRL + Qt::Key_M ) );
     actionCollection()->addAction("send_workpackage", actionMailWorkpackage );
     connect( actionMailWorkpackage, SIGNAL( triggered( bool ) ), SLOT( slotMailWorkpackage() ) );
@@ -1465,7 +1535,8 @@ void TaskWorkPackageView::slotSplitView()
 void TaskWorkPackageView::slotOptions()
 {
     kDebug(planDbg());
-    SplitItemViewSettupDialog *dlg = new SplitItemViewSettupDialog( m_view, this );
+    SplitItemViewSettupDialog *dlg = new SplitItemViewSettupDialog( this, m_view, this );
+    dlg->addPrintingOptions();
     connect(dlg, SIGNAL(finished(int)), SLOT(slotOptionsFinished(int)));
     dlg->show();
     dlg->raise();
