@@ -1,5 +1,5 @@
 /* This file is part of the KDE project
- Copyright (C) 2009 Dag Andersen <danders@get2net.dk>
+ Copyright (C) 2009, 2012 Dag Andersen <danders@get2net.dk>
 
  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Library General Public
@@ -51,6 +51,8 @@
 
 #include <QDomDocument>
 
+#include "debugarea.h"
+
 using namespace KPlato;
 
 namespace KPlatoWork
@@ -80,7 +82,8 @@ WorkPackage::WorkPackage( Project *project, bool fromProjectStore )
         // should be only one manager
         project->setCurrentSchedule( m_project->scheduleManagers().first()->scheduleId() );
     }
-    connect( project, SIGNAL( changed() ), this, SLOT( projectChanged() ) );
+    connect( project, SIGNAL( projectChanged() ), this, SLOT( projectChanged() ) );
+
 }
 
 WorkPackage::~WorkPackage()
@@ -100,7 +103,7 @@ void WorkPackage::setSettings( const WorkPackageSettings &settings )
 //TODO find a way to know when changes are undone
 void WorkPackage::projectChanged()
 {
-    kDebug();
+    kDebug(planworkDbg());
     setModified( true );
 }
 
@@ -132,8 +135,9 @@ bool WorkPackage::addChild( Part */*part*/, const Document *doc )
 
 void WorkPackage::slotChildModified( bool mod )
 {
-    kDebug()<<mod;
+    kDebug(planworkDbg())<<mod;
     emit modified( isModified() );
+    emit saveWorkPackage( this );
 }
 
 void WorkPackage::removeChild( DocumentChild *child )
@@ -174,10 +178,10 @@ bool WorkPackage::loadXML( const KoXmlElement &element, XMLLoaderObject &status
             continue;
         }
         KoXmlElement e = n.toElement();
-        kDebug()<<e.tagName();
+        kDebug(planworkDbg())<<e.tagName();
         if ( e.tagName() == "project" ) {
             status.setProject( m_project );
-            kDebug()<<"loading new project";
+            kDebug(planworkDbg())<<"loading new project";
             if ( ! ( ok = m_project->load( e, status ) ) ) {
                 status.addMsg( XMLLoaderObject::Errors, "Loading of work package failed" );
                 KMessageBox::error( 0, i18n( "Failed to load project: %1" , m_project->name() ) );
@@ -191,7 +195,7 @@ bool WorkPackage::loadXML( const KoXmlElement &element, XMLLoaderObject &status
                 continue;
             }
             KoXmlElement e = n.toElement();
-            kDebug()<<e.tagName();
+            kDebug(planworkDbg())<<e.tagName();
             if ( e.tagName() == "workpackage" ) {
                 Task *t = static_cast<Task*>( m_project->childNode( 0 ) );
                 t->workPackage().setOwnerName( e.attribute( "owner" ) );
@@ -199,16 +203,16 @@ bool WorkPackage::loadXML( const KoXmlElement &element, XMLLoaderObject &status
 
                 Resource *r = m_project->findResource( t->workPackage().ownerId() );
                 if ( r == 0 ) {
-                    kDebug()<<"Cannot find resource id!!"<<t->workPackage().ownerId()<<t->workPackage().ownerName();
+                    kDebug(planworkDbg())<<"Cannot find resource id!!"<<t->workPackage().ownerId()<<t->workPackage().ownerName();
                 }
-                kDebug()<<"is this me?"<<t->workPackage().ownerName();
+                kDebug(planworkDbg())<<"is this me?"<<t->workPackage().ownerName();
                 KoXmlNode ch = e.firstChild();
                 for ( ; ! ch.isNull(); ch = ch.nextSibling() ) {
                     if ( ! ch.isElement() ) {
                         continue;
                     }
                     KoXmlElement el = ch.toElement();
-                    kDebug()<<el.tagName();
+                    kDebug(planworkDbg())<<el.tagName();
                     if ( el.tagName() == "settings" ) {
                         m_settings.loadXML( el );
                     }
@@ -232,11 +236,11 @@ bool WorkPackage::loadKPlatoXML( const KoXmlElement &element, XMLLoaderObject &s
             continue;
         }
         KoXmlElement e = n.toElement();
-        kDebug()<<e.tagName();
+        kDebug(planworkDbg())<<e.tagName();
         if ( e.tagName() == "project" ) {
             status.setProject( m_project );
             KPlatoXmlLoader loader( status, m_project );
-            kDebug()<<"loading new project";
+            kDebug(planworkDbg())<<"loading new project";
             if ( ! ( ok = loader.load( m_project, e, status ) ) ) {
                 status.addMsg( XMLLoaderObject::Errors, "Loading of work package failed" );
                 KMessageBox::error( 0, i18n( "Failed to load project: %1" , m_project->name() ) );
@@ -250,7 +254,7 @@ bool WorkPackage::loadKPlatoXML( const KoXmlElement &element, XMLLoaderObject &s
                 continue;
             }
             KoXmlElement e = n.toElement();
-            kDebug()<<e.tagName();
+            kDebug(planworkDbg())<<e.tagName();
             if ( e.tagName() == "workpackage" ) {
                 Task *t = static_cast<Task*>( m_project->childNode( 0 ) );
                 t->workPackage().setOwnerName( e.attribute( "owner" ) );
@@ -258,16 +262,16 @@ bool WorkPackage::loadKPlatoXML( const KoXmlElement &element, XMLLoaderObject &s
 
                 Resource *r = m_project->findResource( t->workPackage().ownerId() );
                 if ( r == 0 ) {
-                    kDebug()<<"Cannot find resource id!!"<<t->workPackage().ownerId()<<t->workPackage().ownerName();
+                    kDebug(planworkDbg())<<"Cannot find resource id!!"<<t->workPackage().ownerId()<<t->workPackage().ownerName();
                 }
-                kDebug()<<"is this me?"<<t->workPackage().ownerName();
+                kDebug(planworkDbg())<<"is this me?"<<t->workPackage().ownerName();
                 KoXmlNode ch = e.firstChild();
                 for ( ; ! ch.isNull(); ch = ch.nextSibling() ) {
                     if ( ! ch.isElement() ) {
                         continue;
                     }
                     KoXmlElement el = ch.toElement();
-                    kDebug()<<el.tagName();
+                    kDebug(planworkDbg())<<el.tagName();
                     if ( el.tagName() == "settings" ) {
                         m_settings.loadXML( el );
                     }
@@ -300,7 +304,7 @@ bool WorkPackage::saveNativeFormat( Part */*part*/, const QString &path )
         KMessageBox::error( 0, i18n("Cannot save to empty filename") );
         return false;
     }
-    kDebug()<<node()->name()<<path;
+    kDebug(planworkDbg())<<node()->name()<<path;
     KoStore* store = KoStore::createStore(path, KoStore::Write, "application/x-vnd.kde.plan.work", KoStore::Auto );
     if (store->bad()) {
         KMessageBox::error( 0, i18n("Could not create the file for saving") );
@@ -310,7 +314,7 @@ bool WorkPackage::saveNativeFormat( Part */*part*/, const QString &path )
     if (store->open("root")) {
         KoStoreDevice dev(store);
         if ( ! saveToStream(&dev) || ! store->close() ) {
-            kDebug() << "saveToStream failed";
+            kDebug(planworkDbg()) << "saveToStream failed";
             delete store;
             return false;
         }
@@ -336,7 +340,7 @@ bool WorkPackage::saveNativeFormat( Part */*part*/, const QString &path )
 
 bool WorkPackage::completeSaving( KoStore *store )
 {
-    kDebug();
+    kDebug(planworkDbg());
     KoStore *oldstore = KoStore::createStore( filePath(), KoStore::Read, "", KoStore::Zip );
     if ( oldstore->bad() ) {
         KMessageBox::error( 0, i18n( "Failed to open store:\n %1", filePath() ) );
@@ -350,7 +354,7 @@ bool WorkPackage::completeSaving( KoStore *store )
     }
 
     // First get all open documents
-    kDebug()<<m_childdocs.count();
+    kDebug(planworkDbg())<<m_childdocs.count();
     foreach ( DocumentChild *cd, m_childdocs ) {
         if ( ! cd->saveToStore( store ) ) {
         }
@@ -405,9 +409,9 @@ void WorkPackage::removeFile()
 
 void WorkPackage::saveToProjects( Part *part )
 {
-    kDebug();
+    kDebug(planworkDbg());
     QString path = fileName( part );
-    kDebug()<<node()->name();
+    kDebug(planworkDbg())<<node()->name();
     if ( saveNativeFormat( part, path ) ) {
         m_fromProjectStore = true;
         m_filePath = path;
@@ -463,13 +467,13 @@ bool WorkPackage::copyFile( KoStore *from, KoStore *to, const QString &filename
         KMessageBox::error( 0, i18n( "Failed write file:\n %1", filename ) );
         return false;
     }
-    kDebug()<<"Copied file:"<<filename;
+    kDebug(planworkDbg())<<"Copied file:"<<filename;
     return true;
 }
 
 QDomDocument WorkPackage::saveXML()
 {
-    kDebug();
+    kDebug(planworkDbg());
     QDomDocument document( "plan-workpackage" );
 
     document.appendChild( document.createProcessingInstruction(
@@ -499,7 +503,7 @@ QDomDocument WorkPackage::saveXML()
 
 void WorkPackage::merge( Part *part, const WorkPackage *wp, KoStore *store )
 {
-    kDebug();
+    kDebug(planworkDbg());
     const Node *from = wp->node();
     Node *to = node();
 
@@ -522,7 +526,7 @@ void WorkPackage::merge( Part *part, const WorkPackage *wp, KoStore *store )
 
     if ( from->type() == Node::Type_Task && from->type() == Node::Type_Task ) {
         if ( static_cast<Task*>( to )->workPackage().ownerId() != static_cast<const Task*>( from )->workPackage().ownerId() ) {
-            kDebug()<<"merge:"<<"different owners"<<static_cast<const Task*>( from )->workPackage().ownerName()<<static_cast<Task*>( to )->workPackage().ownerName();
+            kDebug(planworkDbg())<<"merge:"<<"different owners"<<static_cast<const Task*>( from )->workPackage().ownerName()<<static_cast<Task*>( to )->workPackage().ownerName();
             if ( static_cast<Task*>( to )->workPackage().ownerId().isEmpty() ) {
                 //TODO cmd
                 static_cast<Task*>( to )->workPackage().setOwnerId( static_cast<const Task*>( from )->workPackage().ownerId() );
@@ -536,32 +540,47 @@ void WorkPackage::merge( Part *part, const WorkPackage *wp, KoStore *store )
                 // update ? what if open, modified ...
                 if ( doc->type() == Document::Type_Product ) {
                     //### FIXME. user feedback
-                    kWarning()<<"We do not update existing deliverables";
+                    kWarning()<<"We do not update existing deliverables (except name change)";
+                    if ( doc->name() != org->name() ) {
+                        m->addCommand( new DocumentModifyNameCmd( org, doc->name() ) );
+                    }
                 } else {
+                    if ( doc->name() != org->name() ) {
+                        m->addCommand( new DocumentModifyNameCmd( org, doc->name() ) );
+                    }
                     if ( doc->sendAs() != org->sendAs() ) {
                         m->addCommand( new DocumentModifySendAsCmd( org, doc->sendAs() ) );
                     }
                     if ( doc->sendAs() == Document::SendAs_Copy ) {
-                        kDebug()<<"Update existing doc:"<<org->url();
+                        kDebug(planworkDbg())<<"Update existing doc:"<<org->url();
                         openNewDocument( org, store );
                     }
                 }
             } else {
-                kDebug()<<"new document:"<<doc->typeToString(doc->type())<<doc->url();
+                kDebug(planworkDbg())<<"new document:"<<doc->typeToString(doc->type())<<doc->url();
                 Document *newdoc = new Document( *doc );
                 m->addCommand( new DocumentAddCmd( to->documents(), newdoc ) );
                 if ( doc->sendAs() == Document::SendAs_Copy ) {
-                    kDebug()<<"Copy file";
+                    kDebug(planworkDbg())<<"Copy file";
                     openNewDocument( newdoc, store );
                 }
             }
         }
     }
+    const Project *fromProject = wp->project();
+    Project *toProject = m_project;
+    const ScheduleManager *fromSm = fromProject->scheduleManagers().value( 0 );
+    Q_ASSERT( fromSm );
+    ScheduleManager *toSm = toProject->scheduleManagers().value( 0 );
+    Q_ASSERT( toSm );
+    if ( fromSm->managerId() != toSm->managerId() || fromSm->scheduleId() != toSm->scheduleId() ) {
+        // rescheduled, update schedules
+        m->addCommand( new CopySchedulesCmd( *fromProject, *toProject ) );
+    }
     if ( m->isEmpty() ) {
         delete m;
     } else {
         part->addCommand( m );
-        setModified( true ); // FIXME needs to follow redo/undo
     }
 }
 
@@ -581,7 +600,7 @@ void WorkPackage::openNewDocument( const Document *doc, KoStore *store )
 
 int WorkPackage::queryClose( Part *part )
 {
-    kDebug()<<isModified();
+    kDebug(planworkDbg())<<isModified();
     QString name = node()->name();
     QStringList lst;
     if ( ! m_childdocs.isEmpty() ) {
@@ -602,11 +621,11 @@ int WorkPackage::queryClose( Part *part )
 
         switch (result) {
             case KMessageBox::Continue: {
-                kDebug()<<"Continue";
+                kDebug(planworkDbg())<<"Continue";
                 break;
             }
             default: // case KMessageBox::Cancel :
-                kDebug()<<"Cancel";
+                kDebug(planworkDbg())<<"Cancel";
                 return KMessageBox::Cancel;
                 break;
         }
@@ -622,15 +641,15 @@ int WorkPackage::queryClose( Part *part )
 
     switch (res) {
         case KMessageBox::Yes: {
-            kDebug()<<"Yes";
+            kDebug(planworkDbg())<<"Yes";
             saveToProjects( part );
             break;
         }
         case KMessageBox::No:
-            kDebug()<<"No";
+            kDebug(planworkDbg())<<"No";
             break;
         default: // case KMessageBox::Cancel :
-            kDebug()<<"Cancel";
+            kDebug(planworkDbg())<<"Cancel";
             break;
     }
     return res;
@@ -655,7 +674,7 @@ KUrl WorkPackage::extractFile( const Document *doc, KoStore *store )
     //FIXME: should use a special tmp dir
     QString tmp = KStandardDirs::locateLocal( "tmp", QString(), false );
     KUrl url( tmp + doc->url().fileName() );
-    kDebug()<<"Extract: "<<doc->url().fileName()<<" -> "<<url.pathOrUrl();
+    kDebug(planworkDbg())<<"Extract: "<<doc->url().fileName()<<" -> "<<url.pathOrUrl();
     if ( ! store->extractFile( doc->url().fileName(), url.path() ) ) {
         KMessageBox::error( 0, i18n( "<p>Work package <b>'%1'</b></p><p>Could not extract file:</p><p>%2</p>", node()->name(), doc->url().fileName() ) );
         return KUrl();
@@ -715,6 +734,93 @@ void ModifyPackageSettingsCmd::unexecute()
     m_wp->setSettings( m_oldvalue );
 }
 
+//---------------------
+CopySchedulesCmd::CopySchedulesCmd( const Project &fromProject, Project &toProject, const QString &name )
+    : NamedCommand( name ),
+      m_project( toProject )
+{
+    QDomDocument olddoc;
+    QDomElement e = olddoc.createElement( "old" );
+    olddoc.appendChild( e );
+    toProject.save( e );
+    m_olddoc = olddoc.toString();
+
+    QDomDocument newdoc;
+    e = newdoc.createElement( "new" );
+    newdoc.appendChild( e );
+    fromProject.save( e );
+    m_newdoc = newdoc.toString();
+}
+void CopySchedulesCmd::execute()
+{
+    load( m_newdoc );
+}
+void CopySchedulesCmd::unexecute()
+{
+    load( m_olddoc );
+}
+
+void CopySchedulesCmd::load( const QString &doc )
+{
+    clearSchedules();
+
+    KoXmlDocument d;
+    d.setContent( doc );
+    KoXmlElement proj = d.documentElement().namedItem( "project").toElement();
+    Q_ASSERT( ! proj.isNull() );
+    KoXmlElement task = proj.namedItem( "task").toElement();
+    Q_ASSERT( ! task.isNull() );
+    KoXmlElement ts = task.namedItem( "schedules").namedItem( "schedule").toElement();
+    Q_ASSERT( ! ts.isNull() );
+    KoXmlElement ps = proj.namedItem( "schedules").namedItem( "plan" ).toElement();
+    Q_ASSERT( ! ps.isNull() );
+
+    XMLLoaderObject status;
+    status.setProject( &m_project );
+    status.setVersion( PLAN_FILE_SYNTAX_VERSION );
+    // task first
+    NodeSchedule *ns = new NodeSchedule();
+    if ( ns->loadXML( ts, status ) ) {
+        kDebug(planworkDbg())<<ns->name()<<ns->type()<<ns->id();
+        ns->setNode( m_project.childNode( 0 ) );
+        m_project.childNode( 0 )->addSchedule( ns );
+    } else {
+        Q_ASSERT( false );
+        delete ns;
+    }
+    // schedule manager next (includes main schedule and resource schedule)
+    ScheduleManager *sm = new ScheduleManager( m_project );
+    if ( sm->loadXML( ps, status ) ) {
+        m_project.addScheduleManager( sm );
+    } else {
+        Q_ASSERT( false );
+        delete sm;
+    }
+    if ( sm ) {
+        m_project.setCurrentSchedule( sm->scheduleId() );
+    }
+    m_project.childNode( 0 )->changed();
+}
+
+void CopySchedulesCmd::clearSchedules()
+{
+    foreach ( Schedule *s, m_project.schedules() ) {
+        m_project.takeSchedule( s );
+    }
+    foreach ( Schedule *s, m_project.childNode( 0 )->schedules() ) {
+        foreach ( Appointment *a, s->appointments() ) {
+            if ( a->resource() && a->resource()->resource() ) {
+                a->resource()->resource()->takeSchedule( a->resource() );
+            }
+        }
+        m_project.childNode( 0 )->takeSchedule( s );
+    }
+    foreach ( ScheduleManager *sm,  m_project.scheduleManagers() ) {
+        m_project.takeScheduleManager( sm );
+        delete sm;
+    }
+}
+
 
 }  //KPlatoWork namespace
 
