@@ -24,11 +24,11 @@
 
 #include <kdebug.h>
 #include <klocale.h>
-#include <kicon.h>
 #include <KFileDialog>
 #include <KInputDialog>
 #include <KAction>
 
+#include <KoIcon.h>
 #include <KoCanvasBase.h>
 #include <KoSelection.h>
 #include <KoShapeManager.h>
@@ -87,15 +87,15 @@ SimpleEntryTool::SimpleEntryTool( KoCanvasBase* canvas )
     QActionGroup* actionGroup = new QActionGroup(this);
     connect(actionGroup, SIGNAL(triggered(QAction*)), this, SLOT(activeActionChanged(QAction*)));
 
-    KAction* importAction = new KAction(KIcon("document-import"), i18n("Import"), this);
+    KAction* importAction = new KAction(koIcon("document-import"), i18n("Import"), this);
     addAction("import", importAction);
     connect(importAction, SIGNAL(triggered()), this, SLOT(importSheet()));
 
-    KAction* exportAction = new KAction(KIcon("document-export"), i18n("Export"), this);
+    KAction* exportAction = new KAction(koIcon("document-export"), i18n("Export"), this);
     addAction("export", exportAction);
     connect(exportAction, SIGNAL(triggered()), this, SLOT(exportSheet()));
 
-    KAction* addBars = new KAction(KIcon("list-add"), i18n("Add measures"), this);
+    KAction* addBars = new KAction(koIcon("list-add"), i18n("Add measures"), this);
     addAction("add_bars", addBars);
     connect(addBars, SIGNAL(triggered()), this, SLOT(addBars()));
 
