@@ -87,8 +87,9 @@ void ChangeListLevelCommand::redo()
         UndoRedoFinalizer finalizer(this);
         for (int i = 0; i < m_blocks.size(); ++i) {
             m_lists.value(i)->updateStoredList(m_blocks.at(i));
-            if (KoTextBlockData *userData = dynamic_cast<KoTextBlockData*>(m_blocks.at(i).userData()))
-                userData->setCounterWidth(-1.0);
+            QTextBlock currentBlock(m_blocks.at(i));
+            KoTextBlockData userData(currentBlock);
+            userData.setCounterWidth(-1.0);
         }
     }
     else {
@@ -121,9 +122,10 @@ void ChangeListLevelCommand::undo()
     for (int i = 0; i < m_blocks.size(); ++i) {
         if (m_blocks.at(i).textList())
             m_lists.value(i)->updateStoredList(m_blocks.at(i));
-        if (KoTextBlockData *userData = dynamic_cast<KoTextBlockData*>(m_blocks.at(i).userData()))
-            userData->setCounterWidth(-1.0);
 
+        QTextBlock currentBlock(m_blocks.at(i));
+        KoTextBlockData userData(currentBlock);
+        userData.setCounterWidth(-1.0);
     }
 }
 
