@@ -148,10 +148,18 @@ void SimpleParagraphWidget::fillListButtons()
             textCharFormat.setFontWeight(QFont::Normal);
             cursor.setCharFormat(textCharFormat);
 
+            QTextBlock cursorBlock = cursor.block();
+            KoTextBlockData data(cursorBlock);
             cursor.insertText("----");
             listStyle.applyStyle(cursor.block(),1);
+            cursorBlock = cursor.block();
+            KoTextBlockData data1(cursorBlock);
             cursor.insertText("\n----");
+            cursorBlock = cursor.block();
+            KoTextBlockData data2(cursorBlock);
             cursor.insertText("\n----");
+            cursorBlock = cursor.block();
+            KoTextBlockData data3(cursorBlock);
 
             KoTextDocumentLayout *lay = dynamic_cast<KoTextDocumentLayout*>(textShape.textShapeData()->document()->documentLayout());
             if(lay)
@@ -297,7 +305,8 @@ void SimpleParagraphWidget::listStyleChanged(int id)
     KoListLevelProperties llp;
     llp.setStyle(static_cast<KoListStyle::Style>(id));
     llp.setLevel(1);
-    m_tool->textEditor()->setListProperties(llp);
+    KoTextEditor::ChangeListFlags flags(KoTextEditor::AutoListStyle);
+    m_tool->textEditor()->setListProperties(llp, flags);
 }
 
 void SimpleParagraphWidget::styleSelected(int index)
