@@ -1160,6 +1160,12 @@ bool Cell::saveOdf(KoXmlWriter& xmlwriter, KoGenStyles &mainStyles,
                     // if the origin cell was a default cell,
                     // we count the default cells
                     repeated = nextCell.column() - j + 1;
+
+                    // check if any of the empty/default cells we skipped contained anchored shapes
+                    int shapeColumn = tableContext.nextAnchoredShape(sheet(), row, column);
+                    if (shapeColumn) {
+                        repeated = qMin(repeated, shapeColumn - column);
+                    }
                 }
                 // otherwise we just stop here to process the adjacent
                 // cell in the next iteration of the outer loop
@@ -1168,7 +1174,7 @@ bool Cell::saveOdf(KoXmlWriter& xmlwriter, KoGenStyles &mainStyles,
             }
 
             if (nextCell.isPartOfMerged() || nextCell.doesMergeCells() ||
-                    !nextCell.comment().isEmpty() || tableContext.cellHasAnchoredShapes(sheet(), row, column) ||
+                    !nextCell.comment().isEmpty() || tableContext.cellHasAnchoredShapes(sheet(), row, nextCell.column()) ||
                     !(nextCell.style() == cellStyle && nextCell.conditions() == conditions())) {
                 break;
             }
@@ -1192,19 +1198,6 @@ bool Cell::saveOdf(KoXmlWriter& xmlwriter, KoGenStyles &mainStyles,
         //kDebug(36003) <<"Formula found";
         QString formula = Odf::encodeFormula(userInput(), locale());
         xmlwriter.addAttribute("table:formula", formula);
-    } else if (!link().isEmpty()) {
-        //kDebug(36003)<<"Link found";
-        xmlwriter.startElement("text:p");
-        xmlwriter.startElement("text:a");
-        const QString url = link();
-        //Reference cell is started by '#'
-        if (Util::localReferenceAnchor(url))
-            xmlwriter.addAttribute("xlink:href", ('#' + url));
-        else
-            xmlwriter.addAttribute("xlink:href", url);
-        xmlwriter.addTextNode(userInput());
-        xmlwriter.endElement();
-        xmlwriter.endElement();
     }
 
     if (doesMergeCells()) {
@@ -1218,6 +1211,24 @@ bool Cell::saveOdf(KoXmlWriter& xmlwriter, KoGenStyles &mainStyles,
             xmlwriter.addAttribute("table:number-rows-spanned", QString::number(rowSpan));
     }
 
+    saveOdfAnnotation(xmlwriter);
+
+    if (!isFormula() && !link().isEmpty()) {
+        //kDebug(36003)<<"Link found";
+        xmlwriter.startElement("text:p");
+        xmlwriter.startElement("text:a");
+        const QString url = link();
+        //Reference cell is started by '#'
+        if (Util::localReferenceAnchor(url))
+            xmlwriter.addAttribute("xlink:href", ('#' + url));
+        else
+            xmlwriter.addAttribute("xlink:href", url);
+        xmlwriter.addAttribute("xlink:type", "simple");
+        xmlwriter.addTextNode(userInput());
+        xmlwriter.endElement();
+        xmlwriter.endElement();
+    }
+
     if (!isEmpty() && link().isEmpty()) {
         QSharedPointer<QTextDocument> doc = richText();
         if (doc) {
@@ -1247,20 +1258,22 @@ bool Cell::saveOdf(KoXmlWriter& xmlwriter, KoGenStyles &mainStyles,
             const QPointF bottomRight = shape->boundingRect().bottomRight();
             qreal endX = 0.0;
             qreal endY = 0.0;
-            const int col = sheet()->leftColumn(bottomRight.x(), endX);
-            const int row = sheet()->topRow(bottomRight.y(), endY);
-            shape->setAdditionalAttribute("table:end-cell-address", Cell(sheet(), col, row).name());
-            shape->setAdditionalAttribute("table:end-x", QString::number(bottomRight.x() - endX));
-            shape->setAdditionalAttribute("table:end-y", QString::number(bottomRight.y() - endY));
-            shapes[i]->saveOdf(tableContext.shapeContext);
+            const int scol = sheet()->leftColumn(bottomRight.x(), endX);
+            const int srow = sheet()->topRow(bottomRight.y(), endY);
+            qreal offsetX = sheet()->columnPosition(column);
+            qreal offsetY = sheet()->rowPosition(row);
+            tableContext.shapeContext.addShapeOffset(shape, QTransform::fromTranslate(-offsetX, -offsetY));
+            shape->setAdditionalAttribute("table:end-cell-address", Region(QPoint(scol, srow)).saveOdf());
+            shape->setAdditionalAttribute("table:end-x", QString::number(bottomRight.x() - endX) + "pt");
+            shape->setAdditionalAttribute("table:end-y", QString::number(bottomRight.y() - endY) + "pt");
+            shape->saveOdf(tableContext.shapeContext);
             shape->removeAdditionalAttribute("table:end-cell-address");
             shape->removeAdditionalAttribute("table:end-x");
             shape->removeAdditionalAttribute("table:end-y");
+            tableContext.shapeContext.removeShapeOffset(shape);
         }
     }
 
-    saveOdfAnnotation(xmlwriter);
-
     xmlwriter.endElement();
     return true;
 }
