@@ -54,9 +54,12 @@ class KoOasisSettings;
 class KoDocumentResourceManager;
 class KoStore;
 class KoXmlWriter;
+class KoView;
+class KoPart;
 
 #define MIME_TYPE "application/x-kspread"
 
+
 namespace Calligra
 {
 namespace Sheets
@@ -84,7 +87,7 @@ public:
      * @param parent the parent object
      * @param singleViewMode enables single view mode, if @c true
      */
-    explicit Doc(QObject* parent = 0);
+    explicit Doc(KoPart *part = 0);
 
     /**
      * Destroys the document.
@@ -124,8 +127,6 @@ public:
 
     virtual bool loadChildren(KoStore* _store);
 
-    virtual void addView(KoView *_view);
-
     bool docData(QString const & xmlTag, QDomDocument & data);
 
     // reimplemented; paints the thumbnail
@@ -165,16 +166,16 @@ Q_SIGNALS:
      */
     void updateView();
 
+    /**
+     * Emitted, if all editors have to be closed.
+     */
+    void closeEditor(bool);
+
 protected Q_SLOTS:
-    virtual void openTemplate(const KUrl& url);
-
     void sheetAdded(Sheet* sheet);
+
 protected:
 
-    KoView* createViewInstance(QWidget* parent);
-
-    QGraphicsItem *createCanvasItem();
-
     /**
      * @reimp Overloaded function of KoDocument.
      */
