@@ -322,8 +322,8 @@ void RowHeader::mouseMove(KoPointerEvent* _ev)
     if (!sheet)
         return;
 
-    double ev_PosY = m_pCanvas->zoomHandler()->unzoomItY(_ev->pos().y()) + m_pCanvas->yOffset();
-    double dHeight = m_pCanvas->zoomHandler()->unzoomItY(height());
+    qreal ev_PosY = m_pCanvas->zoomHandler()->unzoomItY(_ev->pos().y()) + m_pCanvas->yOffset();
+    qreal dHeight = m_pCanvas->zoomHandler()->unzoomItY(height());
 
     // The button is pressed and we are resizing ?
     if (m_bResize) {
@@ -334,7 +334,7 @@ void RowHeader::mouseMove(KoPointerEvent* _ev)
     else if (m_bSelection) {
         qreal y;
         int row = sheet->topRow(ev_PosY, y);
-        if (row > KS_rowMax)
+        if (row > KS_rowMax || row <= 0)
             return;
 
         QPoint newAnchor = m_pCanvas->selection()->anchor();
@@ -344,7 +344,7 @@ void RowHeader::mouseMove(KoPointerEvent* _ev)
         m_pCanvas->selection()->update(newMarker);
 
         if (_ev->pos().y() < 0)
-            m_pCanvas->setVertScrollBarPos(ev_PosY);
+            m_pCanvas->setVertScrollBarPos(qMax<qreal>(0, ev_PosY));
         else if (_ev->pos().y() > m_pCanvas->height()) {
             if (row < KS_rowMax) {
                 const qreal rowHeight = sheet->rowFormats()->rowHeight(row + 1);
@@ -836,7 +836,7 @@ void ColumnHeader::mouseMove(KoPointerEvent* _ev)
         qreal x;
         int col = sheet->leftColumn(ev_PosX, x);
 
-        if (col > KS_colMax)
+        if (col > KS_colMax || col <= 0)
             return;
 
         QPoint newMarker = m_pCanvas->selection()->marker();
